@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2005 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -73,6 +73,13 @@ extern void _draw_scrollable_frame (DIALOG * d,
 				    int fg_color, int bg);
 extern int isspace (int c);
 
+static void my_handle_scrollable_scroll_click (DIALOG * d, int listsize,
+					       int *offset, int height);
+static void my_handle_scrollable_scroll (DIALOG * d, int listsize, int *index,
+					 int *offset);
+static void my_handle_listbox_click (DIALOG * d);
+
+
 /*==================================================================*/
 /* fonctions                                                        */
 /*==================================================================*/
@@ -81,38 +88,43 @@ extern int isspace (int c);
 /* utilitaires                                                      */
 /*------------------------------------------------------------------*/
 
+/* dotted_rect:
+ *  Draws a dotted rectangle, for showing an object has the input focus.
+ */
 static void
-dotted_rect (int x1, int y1, int x2, int y2, int fg, int bg)
+my_dotted_rect (int x1, int y1, int x2, int y2, int fg, int bg)
 {
+  BITMAP *gui_bmp = gui_get_screen ();
   int x = ((x1 + y1) & 1) ? 1 : 0;
   int c;
 
+  /* two loops to avoid bank switches */
   for (c = x1; c <= x2; c++)
-    {
-      putpixel (screen, c, y1, (((c + y1) & 1) == x) ? fg : bg);
-      putpixel (screen, c, y2, (((c + y2) & 1) == x) ? fg : bg);
-    }
+    putpixel (gui_bmp, c, y1, (((c + y1) & 1) == x) ? fg : bg);
+  for (c = x1; c <= x2; c++)
+    putpixel (gui_bmp, c, y2, (((c + y2) & 1) == x) ? fg : bg);
 
   for (c = y1 + 1; c < y2; c++)
     {
-      putpixel (screen, x1, c, (((c + x1) & 1) == x) ? fg : bg);
-      putpixel (screen, x2, c, (((c + x2) & 1) == x) ? fg : bg);
+      putpixel (gui_bmp, x1, c, (((c + x1) & 1) == x) ? fg : bg);
+      putpixel (gui_bmp, x2, c, (((c + x2) & 1) == x) ? fg : bg);
     }
 }
 
 /* _draw_textbox:
  *  Helper function to draw a textbox object.
  */
-static void my_draw_textbox
-  (char *thetext, int *listsize, int draw, int offset,
-   int wword, int tabsize, int x, int y, int w, int h,
-   int disabled, int fore, int deselect, int disable)
+static void
+my_draw_textbox (char *thetext, int *listsize, int draw, int offset,
+		 int wword, int tabsize, int x, int y, int w, int h,
+		 int disabled, int fore, int deselect, int disable)
 {
+  BITMAP *gui_bmp = gui_get_screen ();
   int fg = fore;
   int y1 = y + 4;
   int x1;
   int len;
-  int ww = w - 4;
+  int ww = w - 6;
   char s[16];
   char text[16];
   char space[16];
@@ -124,6 +136,7 @@ static void my_draw_textbox
   int width;
   int line = 0;
   int i = 0;
+  int noignore;
 
   usetc (s + usetc (s, '.'), 0);
   usetc (text + usetc (text, ' '), 0);
@@ -140,15 +153,13 @@ static void my_draw_textbox
   if (draw)
     {
       /* initial start blanking at the top */
-      rectfill (screen, x + 2, y + 2, x + w - 1, y1 - 1, deselect);
+      rectfill (gui_bmp, x + 2, y + 2, x + w - 3, y1 - 1, deselect);
     }
 
   /* choose the text color */
   if (disabled)
     fg = disable;
 
-  text_mode (deselect);
-
   /* loop over the entire string */
   while (1)
     {
@@ -182,6 +193,7 @@ static void my_draw_textbox
 		{
 		  /* remember where we were */
 		  oldscan = scanned;
+		  noignore = FALSE;
 
 		  /* go backwards looking for start of word */
 		  while (!uisspace (ugetc (scanned)))
@@ -190,7 +202,14 @@ static void my_draw_textbox
 		      if (scanned == printed)
 			{
 			  /* the whole line is filled, so stop here */
-			  scanned = oldscan;
+			  tmp = ptmp = scanned;
+			  while (ptmp != oldscan)
+			    {
+			      ptmp = tmp;
+			      tmp += uwidth (tmp);
+			    }
+			  scanned = ptmp;
+			  noignore = TRUE;
 			  break;
 			}
 		      /* look further backwards to wrap */
@@ -203,8 +222,13 @@ static void my_draw_textbox
 		      scanned = ptmp;
 		    }
 		  /* put the space at the end of the line */
-		  ignore = scanned;
-		  scanned += uwidth (scanned);
+		  if (!noignore)
+		    {
+		      ignore = scanned;
+		      scanned += uwidth (scanned);
+		    }
+		  else
+		    ignore = NULL;
 
 		  /* check for endline at the convenient place */
 		  if (ugetc (scanned) == '\n')
@@ -213,19 +237,21 @@ static void my_draw_textbox
 	      /* we are done parsing the line end */
 	      break;
 	    }
+
 	  /* the character can be added */
 	  scanned += uwidth (scanned);
 	  width += len;
 	}
 
       /* check if we are to print it */
-      if ((draw) && (line >= offset)
-	  && (y1 + text_height (font) < (y + h - 1)))
+      //if ((draw) && (line >= offset)
+      //          && (y1 + text_height (font) < (y + h - 3)))
+      if ((draw) && (line >= offset) && (((y1 + text_height (font) < (y + h - 3))) || (line == 0)))	// ufoot
 	{
 	  x1 = x + 4;
 
 	  /* the initial blank bit */
-	  rectfill (screen, x + 2, y1, x1 - 1, y1 + text_height (font),
+	  rectfill (gui_bmp, x + 2, y1, x1 - 1, y1 + text_height (font),
 		    deselect);
 
 	  /* print up to the marked character */
@@ -245,17 +271,19 @@ static void my_draw_textbox
 		  for (i = 0; i < tabsize; i++)
 		    {
 		      usetc (s + usetc (s, ' '), 0);
-		      textout (screen, font, s, x1, y1, -1);
+		      //textout_ex(gui_bmp, font, s, x1, y1, fg, deselect);
+		      textout_ex (gui_bmp, font, s, x1, y1, -1, deselect);	// ufoot
 		      x1 += text_length (font, s);
 		    }
 		  break;
 
-		  /* print a normal charater */
+		  /* print a normal character */
 		default:
 		  if (printed != ignore)
 		    {
 		      usetc (s + usetc (s, ugetc (printed)), 0);
-		      textout (screen, font, s, x1, y1, -1);
+		      //textout_ex(gui_bmp, font, s, x1, y1, fg, deselect);
+		      textout_ex (gui_bmp, font, s, x1, y1, -1, deselect);	// ufoot
 		      x1 += text_length (font, s);
 		    }
 		}
@@ -264,8 +292,8 @@ static void my_draw_textbox
 	      printed += uwidth (printed);
 	    }
 	  /* the last blank bit */
-	  if (x1 < x + w - 1)
-	    rectfill (screen, x1, y1, x + w - 1, y1 + text_height (font) - 1,
+	  if (x1 <= x + w - 3)
+	    rectfill (gui_bmp, x1, y1, x + w - 3, y1 + text_height (font) - 1,
 		      deselect);
 
 	  /* print the line end */
@@ -281,17 +309,16 @@ static void my_draw_textbox
 	{
 	  /* the under blank bit */
 	  if (draw)
-	    rectfill (screen, x + 1, y1, x + w - 1, y + h - 1, deselect);
+	    rectfill (gui_bmp, x + 1, y1, x + w - 3, y + h - 1, deselect);
 
 	  /* tell how many lines we found */
 	  *listsize = line;
 	  return;
 	}
     }
+
 }
 
-
-
 /* d_textbox_proc:
  *  A text box object. The dp field points to a char * which is the text
  *  to be displayed in the text box. If the text is long, there will be
@@ -305,21 +332,35 @@ static void my_draw_textbox
 int
 my_textbox_proc (int msg, DIALOG * d, int c)
 {
-  int height, bar;
-  int fg_color = (d->flags & D_DISABLED) ? gui_mg_color : d->fg;
+  int height, bar, ret = D_O_K;
+  int start, top, bottom, l;
+  int used, delta;
+  int fg_color;
+  ASSERT (d);
 
+  fg_color = (d->flags & D_DISABLED) ? gui_mg_color : d->fg;
   /* calculate the actual height */
-  height = (d->h - 4) / text_height (font);
+  height = (d->h - 8) / text_height (font);
 
-  if (msg == MSG_DRAW)
+  switch (msg)
     {
+
+    case MSG_START:
+      /* measure how many lines of text we contain */
+      my_draw_textbox (d->dp, &d->d1, 0,	/* DONT DRAW anything */
+		       d->d2, !(d->flags & D_SELECTED), 8,
+		       d->x, d->y, d->w, d->h,
+		       (d->flags & D_DISABLED), 0, 0, 0);
+      break;
+
+    case MSG_DRAW:
       /* tell the object to sort of draw, but only calculate the listsize */
       my_draw_textbox (d->dp, &d->d1, 0,	/* DONT DRAW anything */
 		       d->d2, !(d->flags & D_SELECTED), 8,
 		       d->x, d->y, d->w, d->h,
 		       (d->flags & D_DISABLED), 0, 0, 0);
 
-      if (d->d1 > height)
+      if (d->d1 > height && d->d1 > 1)	// ufoot
 	{
 	  bar = 12;
 	}
@@ -329,29 +370,152 @@ my_textbox_proc (int msg, DIALOG * d, int c)
 	  d->d2 = 0;
 	}
 
+      if (d->d1 <= 1)
+	{
+	  rectfill (screen, d->x, d->y, d->x + d->w, d->y + d->h, d->bg);	// ufoot
+	}
+
       /* now do the actual drawing */
       my_draw_textbox (d->dp, &d->d1, 1, d->d2,
 		       !(d->flags & D_SELECTED), 8,
-		       d->x, d->y, d->w - bar - 1, d->h,
+		       d->x, d->y, d->w - bar, d->h,
 		       (d->flags & D_DISABLED),
 		       fg_color, d->bg, gui_mg_color);
 
-      /* draw the frame around */
-      _draw_scrollable_frame (d, d->d1, d->d2, height, fg_color, d->bg);
-      return D_O_K;
+      if (d->d1 <= 1)
+	{
+	  /*
+	   * If there's only one line, skip the scroll bar. Patched
+	   * for LW by ufoot, to handle 320x240 in a nicer way.
+	   */
+	  rect (screen, d->x, d->y, d->x + d->w, d->y + d->h, fg_color);	// ufoot
+	}
+      else
+	{
+	  /* draw the frame around */
+	  _draw_scrollable_frame (d, d->d1, d->d2, height, fg_color, d->bg);
+	}
+      break;
+
+    case MSG_CLICK:
+      /* figure out if it's on the text or the scrollbar */
+      bar = (d->d1 > height);
+
+      if ((!bar) || (gui_mouse_x () < d->x + d->w - 13))
+	{
+	  /* clicked on the text area */
+	  ret = D_O_K;
+	}
+      else
+	{
+	  /* clicked on the scroll area */
+	  my_handle_scrollable_scroll_click (d, d->d1, &d->d2, height);
+	}
+      break;
+
+    case MSG_CHAR:
+      start = d->d2;
+      used = D_USED_CHAR;
+
+      if (d->d1 > 0)
+	{
+	  if (d->d2 > 0)
+	    top = d->d2 + 1;
+	  else
+	    top = 0;
+
+	  l = (d->h - 8) / text_height (font);
+
+	  bottom = d->d2 + l - 1;
+	  if (bottom >= d->d1 - 1)
+	    bottom = d->d1 - 1;
+	  else
+	    bottom--;
+
+	  if ((c >> 8) == KEY_UP)
+	    d->d2--;
+	  else if ((c >> 8) == KEY_DOWN)
+	    d->d2++;
+	  else if ((c >> 8) == KEY_HOME)
+	    d->d2 = 0;
+	  else if ((c >> 8) == KEY_END)
+	    d->d2 = d->d1 - l;
+	  else if ((c >> 8) == KEY_PGUP)
+	    d->d2 -= (bottom - top) ? bottom - top : 1;
+	  else if ((c >> 8) == KEY_PGDN)
+	    d->d2 += (bottom - top) ? bottom - top : 1;
+	  else
+	    used = D_O_K;
+
+	  /* make sure that the list stays in bounds */
+	  if (d->d2 > d->d1 - l)
+	    d->d2 = d->d1 - l;
+	  if (d->d2 < 0)
+	    d->d2 = 0;
+	}
+      else
+	used = D_O_K;
+
+      /* if we changed something, better redraw... */
+      if (d->d2 != start)
+	d->flags |= D_DIRTY;
+
+      ret = used;
+      break;
+
+    case MSG_WHEEL:
+      l = (d->h - 8) / text_height (font);
+      delta = (l > 3) ? 3 : 1;
+
+      /* scroll, making sure that the list stays in bounds */
+      start = d->d2;
+      d->d2 =
+	(c > 0) ? MAX (0, d->d2 - delta) : MIN (d->d1 - l, d->d2 + delta);
+
+      /* if we changed something, better redraw... */
+      if (d->d2 != start)
+	d->flags |= D_DIRTY;
+
+      ret = D_O_K;
+      break;
+
+    case MSG_WANTFOCUS:
+      /* if we don't have a scrollbar we can't do anything with the focus */
+      if (d->d1 > height)
+	ret = D_WANTFOCUS;
+      break;
+
+    default:
+      ret = D_O_K;
     }
-  else
-    return d_textbox_proc (msg, d, c);
+
+  return ret;
 }
 
+/* d_button_proc:
+ *  A button object (the dp field points to the text string). This object
+ *  can be selected by clicking on it with the mouse or by pressing its 
+ *  keyboard shortcut. If the D_EXIT flag is set, selecting it will close 
+ *  the dialog, otherwise it will toggle on and off.
+ */
 int
 my_button_proc (int msg, DIALOG * d, int c)
 {
+  BITMAP *gui_bmp;
   int state1, state2;
+  int black;
+  int swap;
   int g;
+  ASSERT (d);
 
-  if (msg == MSG_DRAW)
+  LW_MACRO_NOP (c);		// ufoot
+
+  gui_bmp = gui_get_screen ();
+
+  switch (msg)
     {
+
+    case MSG_DRAW:
       if (d->flags & D_SELECTED)
 	{
 	  g = 1;
@@ -365,46 +529,108 @@ my_button_proc (int msg, DIALOG * d, int c)
 	  state2 = d->bg;
 	}
 
-      rectfill (screen, d->x + 1 + g, d->y + 1 + g, d->x + d->w - 2 + g,
-		d->y + d->h - 2 + g, state2);
-      rect (screen, d->x + g, d->y + g, d->x + d->w - 1 + g,
-	    d->y + d->h - 1 + g, state1);
-      text_mode (-1);
-      gui_textout (screen, d->dp, d->x + d->w / 2 + g, d->y + d->h / 2 - text_height (font) / 2 + g,	/*state1 */
-		   -1, TRUE);
+      rectfill (gui_bmp, d->x + 1 + g, d->y + 1 + g, d->x + d->w - 3 + g,
+		d->y + d->h - 3 + g, state2);
+      rect (gui_bmp, d->x + g, d->y + g, d->x + d->w - 2 + g,
+	    d->y + d->h - 2 + g, state1);
+      //gui_textout_ex(gui_bmp, d->dp, d->x+d->w/2+g, d->y+d->h/2-text_height(font)/2+g, state1, -1, TRUE);
+      gui_textout_ex (gui_bmp, d->dp, d->x + d->w / 2 + g, d->y + d->h / 2 - text_height (font) / 2 + g, -1, -1, TRUE);	// ufoot
 
       if (d->flags & D_SELECTED)
 	{
-	  vline (screen, d->x, d->y, d->y + d->h - 1, d->bg);
-	  hline (screen, d->x, d->y, d->x + d->w - 1, d->bg);
+	  vline (gui_bmp, d->x, d->y, d->y + d->h - 2, d->bg);
+	  hline (gui_bmp, d->x, d->y, d->x + d->w - 2, d->bg);
 	}
       else
 	{
-	  vline (screen, d->x + d->w, d->y + 1, d->y + d->h - 1, d->fg);
-	  hline (screen, d->x + 1, d->y + d->h, d->x + d->w, d->fg);
+	  black = makecol (0, 0, 0);
+	  vline (gui_bmp, d->x + d->w - 1, d->y + 1, d->y + d->h - 2, black);
+	  hline (gui_bmp, d->x + 1, d->y + d->h - 1, d->x + d->w - 1, black);
 	}
       if ((d->flags & D_GOTFOCUS) &&
 	  (!(d->flags & D_SELECTED) || !(d->flags & D_EXIT)))
-	dotted_rect (d->x + 1 + g, d->y + 1 + g, d->x + d->w - 2 + g,
-		     d->y + d->h - 2 + g, state1, state2);
-      return D_O_K;
+	my_dotted_rect (d->x + 1 + g, d->y + 1 + g, d->x + d->w - 3 + g,
+			d->y + d->h - 3 + g, state1, state2);
+      break;
+
+    case MSG_WANTFOCUS:
+      return D_WANTFOCUS;
+
+    case MSG_KEY:
+      /* close dialog? */
+      if (d->flags & D_EXIT)
+	{
+	  return D_CLOSE;
+	}
+
+      /* or just toggle */
+      d->flags ^= D_SELECTED;
+      object_message (d, MSG_DRAW, 0);
+      break;
+
+    case MSG_CLICK:
+      /* what state was the button originally in? */
+      state1 = d->flags & D_SELECTED;
+      if (d->flags & D_EXIT)
+	swap = FALSE;
+      else
+	swap = state1;
+
+      /* track the mouse until it is released */
+      while (gui_mouse_b ())
+	{
+	  state2 = ((gui_mouse_x () >= d->x) && (gui_mouse_y () >= d->y) &&
+		    (gui_mouse_x () < d->x + d->w)
+		    && (gui_mouse_y () < d->y + d->h));
+	  if (swap)
+	    state2 = !state2;
+
+	  /* redraw? */
+	  if (((state1) && (!state2)) || ((state2) && (!state1)))
+	    {
+	      d->flags ^= D_SELECTED;
+	      state1 = d->flags & D_SELECTED;
+	      object_message (d, MSG_DRAW, 0);
+	    }
+
+	  /* let other objects continue to animate */
+	  broadcast_dialog_message (MSG_IDLE, 0);
+	}
+
+      /* should we close the dialog? */
+      if ((d->flags & D_SELECTED) && (d->flags & D_EXIT))
+	{
+	  d->flags ^= D_SELECTED;
+	  return D_CLOSE;
+	}
+      break;
     }
-  else
-    return d_button_proc (msg, d, c);
+
+  return D_O_K;
 }
 
+
 /* d_text_proc:
  *  Simple dialog procedure: draws the text string which is pointed to by dp.
  */
 int
 my_text_proc (int msg, DIALOG * d, int c)
 {
-  LW_MACRO_NOP (c);
+  LW_MACRO_NOP (c);		// ufoot
 
+  ASSERT (d);
   if (msg == MSG_DRAW)
     {
-      text_mode (-1);
-      gui_textout (screen, d->dp, d->x, d->y, -1, FALSE);
+      //int fg = (d->flags & D_DISABLED) ? gui_mg_color : d->fg; // ufoot
+      FONT *oldfont = font;
+
+      if (d->dp2)
+	font = d->dp2;
+
+      //gui_textout_ex(gui_get_screen(), d->dp, d->x, d->y, fg, d->bg, FALSE);
+      gui_textout_ex (gui_get_screen (), d->dp, d->x, d->y, -1, d->bg, FALSE);	// ufoot
+
+      font = oldfont;
     }
 
   return D_O_K;
@@ -417,12 +643,21 @@ my_text_proc (int msg, DIALOG * d, int c)
 int
 my_ctext_proc (int msg, DIALOG * d, int c)
 {
-  LW_MACRO_NOP (c);
+  LW_MACRO_NOP (c);		// ufoot
 
+  ASSERT (d);
   if (msg == MSG_DRAW)
     {
-      text_mode (-1);
-      gui_textout (screen, d->dp, d->x, d->y, -1, TRUE);
+      // int fg = (d->flags & D_DISABLED) ? gui_mg_color : d->fg; // ufoot
+      FONT *oldfont = font;
+
+      if (d->dp2)
+	font = d->dp2;
+
+      //gui_textout_ex(gui_get_screen(), d->dp, d->x + d->w/2, d->y, fg, d->bg, TRUE);
+      gui_textout_ex (gui_get_screen (), d->dp, d->x + d->w / 2, d->y, -1, d->bg, TRUE);	// ufoot
+
+      font = oldfont;
     }
 
   return D_O_K;
@@ -445,6 +680,7 @@ my_ctext_proc (int msg, DIALOG * d, int c)
 int
 my_slider_proc (int msg, DIALOG * d, int c)
 {
+  BITMAP *gui_bmp = gui_get_screen ();
   BITMAP *slhan = NULL;
   int oldpos, newpos;
   int sfg;			/* slider foreground color */
@@ -463,6 +699,8 @@ my_slider_proc (int msg, DIALOG * d, int c)
   int delta;
   fixed slratio, slmax, slpos;
   int (*proc) (void *cbpointer, int d2value);
+  int oldval;
+  ASSERT (d);
 
   /* check for slider direction */
   if (d->h < d->w)
@@ -493,25 +731,27 @@ my_slider_proc (int msg, DIALOG * d, int c)
 
       if (vert)
 	{
-	  rectfill (screen, d->x, d->y, d->x + d->w / 2 - 2, d->y + d->h,
+	  rectfill (gui_bmp, d->x, d->y, d->x + d->w / 2 - 2, d->y + d->h - 1,
 		    d->bg);
-	  rectfill (screen, d->x + d->w / 2 - 1, d->y, d->x + d->w / 2 + 1,
-		    d->y + d->h, sfg);
-	  rectfill (screen, d->x + d->w / 2 + 2, d->y, d->x + d->w,
-		    d->y + d->h, d->bg);
+	  rectfill (gui_bmp, d->x + d->w / 2 - 1, d->y, d->x + d->w / 2 + 1,
+		    d->y + d->h - 1, sfg);
+	  rectfill (gui_bmp, d->x + d->w / 2 + 2, d->y, d->x + d->w - 1,
+		    d->y + d->h - 1, d->bg);
 	}
       else
 	{
-	  rectfill (screen, d->x, d->y, d->x + d->w, d->y + d->h / 2 - 2,
+	  rectfill (gui_bmp, d->x, d->y, d->x + d->w - 1, d->y + d->h / 2 - 2,
 		    d->bg);
-	  rectfill (screen, d->x, d->y + d->h / 2 - 1, d->x + d->w,
+	  rectfill (gui_bmp, d->x, d->y + d->h / 2 - 1, d->x + d->w - 1,
 		    d->y + d->h / 2 + 1, sfg);
-	  rectfill (screen, d->x, d->y + d->h / 2 + 2, d->x + d->w,
-		    d->y + d->h, d->bg);
+	  rectfill (gui_bmp, d->x, d->y + d->h / 2 + 2, d->x + d->w - 1,
+		    d->y + d->h - 1, d->bg);
 	}
 
-      rect (screen, d->x, d->y, d->x + d->w, d->y + d->h, sfg);
-      /* ligne du desssus ajoutee par moi pour le cadre */
+      /*
+       * Following line added to draw a box arround the slider
+       */
+      rect (screen, d->x, d->y, d->x + d->w, d->y + d->h, sfg);	// ufoot
 
       /* okay, background and slot are drawn, now draw the handle */
       if (slhan)
@@ -519,14 +759,14 @@ my_slider_proc (int msg, DIALOG * d, int c)
 	  if (vert)
 	    {
 	      slx = d->x + (d->w / 2) - (slhan->w / 2);
-	      sly = d->y + d->h - (hh + slp);
+	      sly = d->y + (d->h - 1) - (hh + slp);
 	    }
 	  else
 	    {
 	      slx = d->x + slp;
 	      sly = d->y + (d->h / 2) - (slhan->h / 2);
 	    }
-	  draw_sprite (screen, slhan, slx, sly);
+	  draw_sprite (gui_bmp, slhan, slx, sly);
 	}
       else
 	{
@@ -534,33 +774,32 @@ my_slider_proc (int msg, DIALOG * d, int c)
 	  if (vert)
 	    {
 	      slx = d->x;
-	      sly = d->y + d->h - (hh + slp);
-	      slw = d->w;
-	      slh = hh;
+	      sly = d->y + (d->h) - (hh + slp);
+	      slw = d->w - 1;
+	      slh = hh - 1;
 	    }
 	  else
 	    {
 	      slx = d->x + slp;
 	      sly = d->y;
-	      slw = hh;
-	      slh = d->h;
+	      slw = hh - 1;
+	      slh = d->h - 1;
 	    }
 
 	  /* draw body */
-	  rectfill (screen, slx + 2, sly, slx + (slw - 2), sly + slh, sfg);
-	  vline (screen, slx + 1, sly + 1, sly + slh - 1, sfg);
-	  vline (screen, slx + slw - 1, sly + 1, sly + slh - 1, sfg);
-	  vline (screen, slx, sly + 2, sly + slh - 2, sfg);
-	  vline (screen, slx + slw, sly + 2, sly + slh - 2, sfg);
-	  vline (screen, slx + 1, sly + 2, sly + slh - 2, d->bg);
-	  hline (screen, slx + 2, sly + 1, slx + slw - 2, d->bg);
-	  putpixel (screen, slx + 2, sly + 2, d->bg);
+	  rectfill (gui_bmp, slx + 2, sly, slx + (slw - 2), sly + slh, sfg);
+	  vline (gui_bmp, slx + 1, sly + 1, sly + slh - 1, sfg);
+	  vline (gui_bmp, slx + slw - 1, sly + 1, sly + slh - 1, sfg);
+	  vline (gui_bmp, slx, sly + 2, sly + slh - 2, sfg);
+	  vline (gui_bmp, slx + slw, sly + 2, sly + slh - 2, sfg);
+	  vline (gui_bmp, slx + 1, sly + 2, sly + slh - 2, d->bg);
+	  hline (gui_bmp, slx + 2, sly + 1, slx + slw - 2, d->bg);
+	  putpixel (gui_bmp, slx + 2, sly + 2, d->bg);
 	}
 
       if (d->flags & D_GOTFOCUS)
-	dotted_rect (d->x + 1, d->y + 1, d->x + d->w - 1, d->y + d->h - 1,
-		     sfg, d->bg);
-      /* coord du dotted rect modifiee par moi , cad +1 et -2 */
+	// my_dotted_rect(d->x, d->y, d->x+d->w-1, d->y+d->h-1, sfg, d->bg);
+	my_dotted_rect (d->x + 1, d->y + 1, d->x + d->w - 1, d->y + d->h - 1, sfg, d->bg);	// ufoot
       break;
 
     case MSG_WANTFOCUS:
@@ -614,6 +853,7 @@ my_slider_proc (int msg, DIALOG * d, int c)
       if (delta)
 	{
 	  oldpos = slp;
+	  oldval = d->d2;
 
 	  while (1)
 	    {
@@ -631,6 +871,25 @@ my_slider_proc (int msg, DIALOG * d, int c)
 
 	  retval = D_USED_CHAR;
 
+	  if (d->d2 != oldval)
+	    {
+	      /* call callback function here */
+	      if (d->dp2)
+		{
+		  proc = d->dp2;
+		  retval |= (*proc) (d->dp3, d->d2);
+		}
+
+	      object_message (d, MSG_DRAW, 0);
+	    }
+	}
+      break;
+
+    case MSG_WHEEL:
+      oldval = d->d2;
+      d->d2 = MID (0, d->d2 + c, d->d1);
+      if (d->d2 != oldval)
+	{
 	  /* call callback function here */
 	  if (d->dp2)
 	    {
@@ -638,9 +897,7 @@ my_slider_proc (int msg, DIALOG * d, int c)
 	      retval |= (*proc) (d->dp3, d->d2);
 	    }
 
-	  show_mouse (NULL);
-	  SEND_MESSAGE (d, MSG_DRAW, 0);
-	  show_mouse (screen);
+	  object_message (d, MSG_DRAW, 0);
 	}
       break;
 
@@ -648,11 +905,11 @@ my_slider_proc (int msg, DIALOG * d, int c)
       /* track the mouse until it is released */
       mp = slp;
 
-      while (mouse_b)
+      while (gui_mouse_b ())
 	{
-	  msx = mouse_x;
-	  msy = mouse_y;
-	  oldpos = d->d2;
+	  msx = gui_mouse_x ();
+	  msy = gui_mouse_y ();
+	  oldval = d->d2;
 	  if (vert)
 	    mp = (d->y + d->h - hmar) - msy;
 	  else
@@ -662,9 +919,9 @@ my_slider_proc (int msg, DIALOG * d, int c)
 	  if (mp > irange - hh)
 	    mp = irange - hh;
 	  slpos = itofix (mp);
-	  slmax = fdiv (slpos, slratio);
+	  slmax = fixdiv (slpos, slratio);
 	  newpos = fixtoi (slmax);
-	  if (newpos != oldpos)
+	  if (newpos != oldval)
 	    {
 	      d->d2 = newpos;
 
@@ -675,12 +932,7 @@ my_slider_proc (int msg, DIALOG * d, int c)
 		  retval |= (*proc) (d->dp3, d->d2);
 		}
 
-	      if (d->d2 != oldpos)
-		{
-		  show_mouse (NULL);
-		  SEND_MESSAGE (d, MSG_DRAW, 0);
-		  show_mouse (screen);
-		}
+	      object_message (d, MSG_DRAW, 0);
 	    }
 
 	  /* let other objects continue to animate */
@@ -692,6 +944,7 @@ my_slider_proc (int msg, DIALOG * d, int c)
   return retval;
 }
 
+
 /* d_edit_proc:
  *  An editable text object (the dp field points to the string). When it
  *  has the input focus (obtained by clicking on it with the mouse), text
@@ -703,11 +956,14 @@ int
 my_edit_proc (int msg, DIALOG * d, int c)
 {
   static int ignore_next_uchar = FALSE;
+  BITMAP *gui_bmp;
   int last_was_space, new_pos, i, k;
   int f, l, p, w, x, fg, b, scroll;
   char buf[16];
   char *s, *t;
-  int rtm;
+  ASSERT (d);
+
+  gui_bmp = gui_get_screen ();
 
   s = d->dp;
   l = ustrlen (s);
@@ -772,21 +1028,12 @@ my_edit_proc (int msg, DIALOG * d, int c)
 	  if (x + w > d->w)
 	    break;
 	  f = ((p == d->d2) && (d->flags & D_GOTFOCUS));
-	  rtm = text_mode ((f) ? fg : d->bg);
-	  textout (screen, font, buf, d->x + x, d->y, (f) ? d->bg : fg);
-	  /*
-	   * Now we redraw with color -1 to use the font's native look
-	   */
-	  text_mode (-1);
-	  textout (screen, font, buf, d->x + x, d->y, -1);
-	  /*
-	   * End of the ugly patch
-	   */
-	  text_mode (rtm);
+	  //textout_ex(gui_bmp, font, buf, d->x+x, d->y, (f) ? d->bg : fg, (f) ? fg : d->bg);
+	  textout_ex (gui_bmp, font, buf, d->x + x, d->y, -1, (f) ? d->fg : d->bg);	// ufoot
 	  x += w;
 	}
       if (x < d->w)
-	rectfill (screen, d->x + x, d->y, d->x + d->w - 1,
+	rectfill (gui_bmp, d->x + x, d->y, d->x + d->w - 1,
 		  d->y + text_height (font) - 1, d->bg);
       break;
 
@@ -809,9 +1056,7 @@ my_edit_proc (int msg, DIALOG * d, int c)
 	    break;
 	}
       d->d2 = MID (0, p, l);
-      scare_mouse ();
       object_message (d, MSG_DRAW, 0);
-      unscare_mouse ();
       break;
 
     case MSG_WANTFOCUS:
@@ -889,9 +1134,7 @@ my_edit_proc (int msg, DIALOG * d, int c)
 	{
 	  if (d->flags & D_EXIT)
 	    {
-	      scare_mouse ();
 	      object_message (d, MSG_DRAW, 0);
-	      unscare_mouse ();
 	      return D_CLOSE;
 	    }
 	  else
@@ -907,22 +1150,19 @@ my_edit_proc (int msg, DIALOG * d, int c)
 	  /* don't process regular keys here: MSG_UCHAR will do that */
 	  break;
 	}
-      scare_mouse ();
       object_message (d, MSG_DRAW, 0);
-      unscare_mouse ();
       return D_USED_CHAR;
 
     case MSG_UCHAR:
-      if ((c >= ' ') && (uisok (c)) && (!ignore_next_uchar))
+      // if ((c >= ' ') && (uisok (c)) && (!ignore_next_uchar))
+      if ((c >= ' ') && (c < 128) && (uisok (c)) && (!ignore_next_uchar))	// ufoot
 	{
 	  if (l < d->d1)
 	    {
 	      uinsert (s, d->d2, c);
 	      d->d2++;
 
-	      scare_mouse ();
 	      object_message (d, MSG_DRAW, 0);
-	      unscare_mouse ();
 	    }
 	  return D_USED_CHAR;
 	}
@@ -933,10 +1173,11 @@ my_edit_proc (int msg, DIALOG * d, int c)
 }
 
 
+
 /* _handle_scrollable_click:
  *  Helper to process a click on a scrollable object.
  */
-void
+static void
 my_handle_scrollable_scroll_click (DIALOG * d, int listsize, int *offset,
 				   int height)
 {
@@ -964,9 +1205,7 @@ my_handle_scrollable_scroll_click (DIALOG * d, int listsize, int *offset,
 	      if (yy != *offset)
 		{
 		  *offset = yy;
-		  scare_mouse ();
 		  object_message (d, MSG_DRAW, 0);
-		  unscare_mouse ();
 		}
 
 	      /* let other objects continue to animate */
@@ -989,9 +1228,7 @@ my_handle_scrollable_scroll_click (DIALOG * d, int listsize, int *offset,
 	  if (yy != *offset)
 	    {
 	      *offset = yy;
-	      scare_mouse ();
 	      object_message (d, MSG_DRAW, 0);
-	      unscare_mouse ();
 	    }
 	}
 
@@ -1001,11 +1238,10 @@ my_handle_scrollable_scroll_click (DIALOG * d, int listsize, int *offset,
 }
 
 
-
 /* _handle_scrollable_scroll:
  *  Helper function to scroll through a scrollable object.
  */
-void
+static void
 my_handle_scrollable_scroll (DIALOG * d, int listsize, int *index,
 			     int *offset)
 {
@@ -1053,12 +1289,11 @@ my_idle_cb (void)
 }
 
 
-
 /* _handle_listbox_click:
  *  Helper to process a click on a listbox, doing hit-testing and moving
  *  the selection.
  */
-void
+static void
 my_handle_listbox_click (DIALOG * d)
 {
   char *sel = d->dp2;
@@ -1103,6 +1338,8 @@ my_handle_listbox_click (DIALOG * d)
 	      else
 		sel[i] = !sel[i];
 	    }
+	  else
+	    sel[i] = TRUE;
 	}
 
       d->d1 = i;
@@ -1115,6 +1352,21 @@ my_handle_listbox_click (DIALOG * d)
 	rest_callback (MID (10, text_height (font) * 16 - d->h - 1, 100),
 		       my_idle_cb);
     }
+  else
+    {
+      if (!(d->flags & D_INTERNAL))
+	{
+	  if (sel)
+	    {
+	      if ((key_shifts & KB_CTRL_FLAG))
+		sel[i] = !sel[i];
+	      else
+		sel[i] = TRUE;
+
+	      d->flags |= D_DIRTY;
+	    }
+	}
+    }
 }
 
 
@@ -1122,14 +1374,14 @@ my_handle_listbox_click (DIALOG * d)
 /* draw_listbox:
  *  Helper function to draw a listbox object.
  */
-void
+static void
 my_draw_listbox (DIALOG * d)
 {
+  BITMAP *gui_bmp = gui_get_screen ();
   int height, listsize, i, len, bar, x, y, w;
   int fg_color, fg, bg;
   char *sel = d->dp2;
   char s[1024];
-  int rtm;
 
   (*(my_getfuncptr) d->dp) (-1, &listsize);
   height = (d->h - 4) / text_height (font);
@@ -1142,16 +1394,29 @@ my_draw_listbox (DIALOG * d)
     {
       if (d->d2 + i < listsize)
 	{
-	  if (d->d2 + i == d->d1)
+	  if (sel)
+	    {
+	      if ((sel[d->d2 + i]) && (d->d2 + i == d->d1))
+		{
+		  fg = d->bg;
+		  bg = fg_color;
+		}
+	      else if (sel[d->d2 + i])
+		{
+		  fg = d->bg;
+		  bg = gui_mg_color;
+		}
+	      else
+		{
+		  fg = fg_color;
+		  bg = d->bg;
+		}
+	    }
+	  else if (d->d2 + i == d->d1)
 	    {
 	      fg = d->bg;
 	      bg = fg_color;
 	    }
-	  else if ((sel) && (sel[d->d2 + i]))
-	    {
-	      fg = d->bg;
-	      bg = gui_mg_color;
-	    }
 	  else
 	    {
 	      fg = fg_color;
@@ -1161,8 +1426,7 @@ my_draw_listbox (DIALOG * d)
 		    (*(my_getfuncptr) d->dp) (i + d->d2, NULL));
 	  x = d->x + 2;
 	  y = d->y + 2 + i * text_height (font);
-	  rtm = text_mode (bg);
-	  rectfill (screen, x, y, x + 7, y + text_height (font) - 1, bg);
+	  rectfill (gui_bmp, x, y, x + 7, y + text_height (font) - 1, bg);
 	  x += 8;
 	  len = ustrlen (s);
 	  while (text_length (font, s) >= MAX (d->w - 1 - (bar ? 22 : 10), 1))
@@ -1170,27 +1434,32 @@ my_draw_listbox (DIALOG * d)
 	      len--;
 	      usetat (s, len, 0);
 	    }
-	  textout (screen, font, s, x, y, -1);
-	  text_mode (rtm);
+	  //textout_ex(gui_bmp, font, s, x, y, fg, bg);
+	  textout_ex (gui_bmp, font, s, x, y, -1, bg);	// ufoot
 	  x += text_length (font, s);
 	  if (x <= d->x + w)
-	    rectfill (screen, x, y, d->x + w, y + text_height (font) - 1, bg);
+	    rectfill (gui_bmp, x, y, d->x + w, y + text_height (font) - 1,
+		      bg);
+	  if (d->d2 + i == d->d1)
+	    my_dotted_rect (d->x + 1, y, d->x + d->w - (bar ? 12 : 0),
+			    y + text_height (font) - 1, d->fg, d->bg);
 	}
       else
 	{
-	  rectfill (screen, d->x + 2, d->y + 2 + i * text_height (font),
+	  rectfill (gui_bmp, d->x + 2, d->y + 2 + i * text_height (font),
 		    d->x + w, d->y + 1 + (i + 1) * text_height (font), d->bg);
 	}
     }
 
   if (d->y + 2 + i * text_height (font) <= d->y + d->h - 3)
-    rectfill (screen, d->x + 2, d->y + 2 + i * text_height (font),
+    rectfill (gui_bmp, d->x + 2, d->y + 2 + i * text_height (font),
 	      d->x + w, d->y + d->h - 3, d->bg);
 
   /* draw frame, maybe with scrollbar */
   _draw_scrollable_frame (d, listsize, d->d2, height, fg_color, d->bg);
 }
 
+
 /* d_list_proc:
  *  A list box object. The dp field points to a function which it will call
  *  to obtain information about the list. This should follow the form:
@@ -1211,6 +1480,7 @@ my_list_proc (int msg, DIALOG * d, int c)
   int listsize, i, bottom, height, bar, orig;
   char *sel = d->dp2;
   int redraw = FALSE;
+  ASSERT (d);
 
   switch (msg)
     {
@@ -1241,11 +1511,7 @@ my_list_proc (int msg, DIALOG * d, int c)
 		    }
 		}
 	      if (redraw)
-		{
-		  scare_mouse ();
-		  object_message (d, MSG_DRAW, 0);
-		  unscare_mouse ();
-		}
+		object_message (d, MSG_DRAW, 0);
 	    }
 	  my_handle_listbox_click (d);
 	  while (gui_mouse_b ())
@@ -1294,9 +1560,7 @@ my_list_proc (int msg, DIALOG * d, int c)
 	  if (i != d->d2)
 	    {
 	      d->d2 = i;
-	      scare_mouse ();
 	      object_message (d, MSG_DRAW, 0);
-	      unscare_mouse ();
 	    }
 	}
       break;
@@ -1378,8 +1642,6 @@ my_list_proc (int msg, DIALOG * d, int c)
   return D_O_K;
 }
 
-
-
 /*------------------------------------------------------------------*/
 BITMAP *
 my_create_bitmap (int w, int h)
