@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2005 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -64,10 +64,11 @@
 
 #define LW_ASM_OFFSET_BITMAP_LINE   64
 
+typedef void *ptr;
 #define LW_ASM_SIZEOF_int            4
-#define LW_ASM_SIZEOF_long           4
 #define LW_ASM_SIZEOF_short          2
 #define LW_ASM_SIZEOF_char           1
+#define LW_ASM_SIZEOF_ptr            4
 
 #define LW_ASM_SIZEOF_MESH_UPDATE    4
 #define LW_ASM_SIZEOF_MESH_STATE     4
@@ -103,9 +104,9 @@ lw_asm_check_struct_align (void)
     int offset_bitmap_line;
 
     LW_ASM_CHECK_SIZEOF (int);
-    LW_ASM_CHECK_SIZEOF (long);
     LW_ASM_CHECK_SIZEOF (short);
     LW_ASM_CHECK_SIZEOF (char);
+    LW_ASM_CHECK_SIZEOF (ptr);
 
     LW_ASM_CHECK_SIZEOF (MESH_UPDATE);
     LW_ASM_CHECK_SIZEOF (MESH_STATE);
