@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2005 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -193,14 +193,23 @@ int MIN_MAP_RES_H[9] = { 0, 60, 90, 120, 150, 180, 240, 360, 480 };
 void
 load_default_options (void)
 {
-#ifdef ALLEGRO_DOS
+#ifdef DOS
   CONFIG_GFX_GAME = 0;
   CONFIG_GFX_MENU = 2;
 #else
   CONFIG_GFX_GAME = 2;
   CONFIG_GFX_MENU = 2;
 #endif
+#ifdef UNIX
+  /*
+   * Under UNIX/X11, we default to windowed mode since
+   * fullscreen modes under Xfree86 can be unconfigured and/or
+   * buggy depending on window manager and other stuff
+   */
+  CONFIG_FULLSCREEN = 0;
+#else
   CONFIG_FULLSCREEN = 1;
+#endif
   CONFIG_VIEWPORT_SIZE = 6;
 
   CONFIG_WAVE_NUMBER[0] = 2;
@@ -281,7 +290,15 @@ load_default_options (void)
   CONFIG_JOYSTICK_ON = 1;
   CONFIG_PAGE_FLIP = 0;
   CONFIG_LANGUAGE = LW_LANG_LANGUAGE_AUTO;
-  CONFIG_WAVE_ON = 1;
+#ifdef ASM
+  /*
+   * We activate waves only if assembly code is available,
+   * else it's not a good idea for it's too slow.
+   */
+  CONFIG_WAVE_ON = STARTUP_ASM ? 1 : 0;
+#else
+  CONFIG_WAVE_ON = 0;
+#endif
 
   CONFIG_FRAMES_PER_SEC_LIMIT = 6;
   CONFIG_ROUNDS_PER_SEC_LIMIT = 4;
