@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2005 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -457,7 +457,7 @@ connect_on_server_keepalive (void *arg)
     {
       if (result == 1)
 	{
-	  if (!lw_protocol_waiting (data->sock, &(data->waited_teams)))
+	  if (!lw_protocol_waiting (&data->sock, &(data->waited_teams)))
 	    {
 	      result = 0;
 	    }
@@ -474,7 +474,7 @@ connect_on_server_keepalive (void *arg)
 		{
 		  if (result == 1)
 		    {
-		      if (!lw_protocol_ask_teamstartinfo (data->sock, i,
+		      if (!lw_protocol_ask_teamstartinfo (&data->sock, i,
 							  &(data->
 							    team_start_info
 							    [i])))
@@ -488,7 +488,7 @@ connect_on_server_keepalive (void *arg)
 		{
 		  lw_netmess_cleanup_arg (data->chat_buffer);
 
-		  if (!lw_protocol_chat_talk (data->sock, data->chat_buffer))
+		  if (!lw_protocol_chat_talk (&data->sock, data->chat_buffer))
 		    {
 		      result = 0;
 		    }
@@ -499,7 +499,7 @@ connect_on_server_keepalive (void *arg)
 	      if (result == 1)
 		{
 		  if (!lw_protocol_chat_listen
-		      (data->sock, &(data->chat_history)))
+		      (&data->sock, &(data->chat_history)))
 		    {
 		      result = 0;
 		    }
@@ -507,7 +507,7 @@ connect_on_server_keepalive (void *arg)
 
 	      if (result == 1 && data->force_start)
 		{
-		  if (!lw_protocol_force_start (data->sock))
+		  if (!lw_protocol_force_start (&data->sock))
 		    {
 		      result = 0;
 		    }
@@ -520,7 +520,7 @@ connect_on_server_keepalive (void *arg)
 
 	      if (result == 1)
 		{
-		  if (!lw_protocol_next (data->sock))
+		  if (!lw_protocol_next (&data->sock))
 		    {
 		      result = 0;
 		    }
@@ -533,7 +533,7 @@ connect_on_server_keepalive (void *arg)
 	       */
 	      if (result == 1)
 		{
-		  if (!lw_protocol_i_am_ready (data->sock))
+		  if (!lw_protocol_i_am_ready (&data->sock))
 		    {
 		      result = 0;
 		    }
