@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2005 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -64,6 +64,7 @@
 #include "exit.h"
 #include "keyboard.h"
 #include "capture.h"
+#include "joystick.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -310,6 +311,7 @@ my_update_dialog (DIALOG_PLAYER * player)
 
   result = update_dialog (player);
   lw_capture_dump_menu ();
+  my_poll_joystick ();
   my_exit_poll ();
 
 #ifdef UNIX
@@ -319,7 +321,8 @@ my_update_dialog (DIALOG_PLAYER * player)
    */
   usleep (100);
 #endif
-  yield_timeslice ();
+  //yield_timeslice (); deprecated
+  rest (0);
 
   return result;
 }
