@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2005 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -309,7 +309,7 @@ my_exit (int code)
 	  disp_graphics_fail_message ();
 	  break;
 	}
-#ifdef ALLEGRO_DOS
+#ifdef DOS
       getch ();
 #endif
       log_println ();
