@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2005 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -233,7 +233,7 @@ display_time (int x, int y, int w, int h)
   buffer[4] = '0' + sec % 10;
   buffer[5] = 0;
 
-  textout (INFO_BAR, font, buffer, x + 1, y + 1, -1);
+  textout_ex (INFO_BAR, font, buffer, x + 1, y + 1, -1, -1);
 }
 
 /*------------------------------------------------------------------*/
