@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2005 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -75,6 +75,22 @@
 #define KEY_JOY2_B1    122
 #define KEY_JOY2_B2    123
 
+extern int JOYSTICK_CONTROL_JOY1_UP;
+extern int JOYSTICK_CONTROL_JOY1_RIGHT;
+extern int JOYSTICK_CONTROL_JOY1_DOWN;
+extern int JOYSTICK_CONTROL_JOY1_LEFT;
+extern int JOYSTICK_CONTROL_JOY1_B1;
+extern int JOYSTICK_CONTROL_JOY1_B2;
+extern int JOYSTICK_CONTROL_JOY1_B3;
+extern int JOYSTICK_CONTROL_JOY1_B4;
+
+extern int JOYSTICK_CONTROL_JOY2_UP;
+extern int JOYSTICK_CONTROL_JOY2_RIGHT;
+extern int JOYSTICK_CONTROL_JOY2_DOWN;
+extern int JOYSTICK_CONTROL_JOY2_LEFT;
+extern int JOYSTICK_CONTROL_JOY2_B1;
+extern int JOYSTICK_CONTROL_JOY2_B2;
+
 /*==================================================================*/
 /* fonctions globales                                               */
 /*==================================================================*/
