@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2005 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -106,54 +106,62 @@ is_touched_key (int i)
       {
       case KEY_JOY1_UP:
 	found = 1;
-	retval = joy_up;
+	retval = JOYSTICK_CONTROL_JOY1_UP;
 	break;
       case KEY_JOY1_RIGHT:
 	found = 1;
-	retval = joy_right;
+	retval = JOYSTICK_CONTROL_JOY1_RIGHT;
 	break;
       case KEY_JOY1_DOWN:
 	found = 1;
-	retval = joy_down;
+	retval = JOYSTICK_CONTROL_JOY1_DOWN;
 	break;
       case KEY_JOY1_LEFT:
 	found = 1;
-	retval = joy_left;
+	retval = JOYSTICK_CONTROL_JOY1_LEFT;
 	break;
 
       case KEY_JOY1_B1:
 	found = 1;
-	retval = joy_b1;
+	retval = JOYSTICK_CONTROL_JOY1_B1;
 	break;
       case KEY_JOY1_B2:
 	found = 1;
-	retval = joy_b2;
+	retval = JOYSTICK_CONTROL_JOY1_B2;
+	break;
+      case KEY_JOY1_B3:
+	found = 1;
+	retval = JOYSTICK_CONTROL_JOY1_B3;
+	break;
+      case KEY_JOY1_B4:
+	found = 1;
+	retval = JOYSTICK_CONTROL_JOY1_B4;
 	break;
 
       case KEY_JOY2_UP:
 	found = 1;
-	retval = joy2_up;
+	retval = JOYSTICK_CONTROL_JOY2_UP;
 	break;
       case KEY_JOY2_RIGHT:
 	found = 1;
-	retval = joy2_right;
+	retval = JOYSTICK_CONTROL_JOY2_RIGHT;
 	break;
       case KEY_JOY2_DOWN:
 	found = 1;
-	retval = joy2_down;
+	retval = JOYSTICK_CONTROL_JOY2_DOWN;
 	break;
       case KEY_JOY2_LEFT:
 	found = 1;
-	retval = joy2_left;
+	retval = JOYSTICK_CONTROL_JOY2_LEFT;
 	break;
 
       case KEY_JOY2_B1:
 	found = 1;
-	retval = joy2_b1;
+	retval = JOYSTICK_CONTROL_JOY2_B1;
 	break;
       case KEY_JOY2_B2:
 	found = 1;
-	retval = joy2_b2;
+	retval = JOYSTICK_CONTROL_JOY2_B2;
 	break;
       }
 
