@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2005 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -73,8 +73,8 @@ int LW_KEYEXCH_SOCK = -1;
 /* static functions                                                 */
 /*==================================================================*/
 
-static int send_keys (int sock, CURSOR * cursors, unsigned int checksum);
-static int recv_keys (int sock, CURSOR * cursors);
+static int send_keys (int *sock, CURSOR * cursors, unsigned int checksum);
+static int recv_keys (int *sock, CURSOR * cursors);
 
 /*==================================================================*/
 /* fonctions                                                        */
@@ -82,7 +82,7 @@ static int recv_keys (int sock, CURSOR * cursors);
 
 /*------------------------------------------------------------------*/
 static int
-send_keys (int sock, CURSOR * cursors, unsigned int checksum)
+send_keys (int *sock, CURSOR * cursors, unsigned int checksum)
 {
   int result = 0;
   int i;
@@ -133,7 +133,7 @@ send_keys (int sock, CURSOR * cursors, unsigned int checksum)
 
 /*------------------------------------------------------------------*/
 static int
-recv_keys (int sock, CURSOR * cursors)
+recv_keys (int *sock, CURSOR * cursors)
 {
   int result = 0;
   int i;
@@ -177,8 +177,8 @@ lw_keyexch_flush (CURSOR * cursors, unsigned int checksum)
   /*
    * It's important to send keys before we receive them
    */
-  result = result && send_keys (LW_KEYEXCH_SOCK, cursors, checksum);
-  result = result && recv_keys (LW_KEYEXCH_SOCK, cursors);
+  result = result && send_keys (&LW_KEYEXCH_SOCK, cursors, checksum);
+  result = result && recv_keys (&LW_KEYEXCH_SOCK, cursors);
 
   return result;
 }
