@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2005 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -133,8 +133,9 @@ palette_128 (DIALOG * d, int x, int y, int w, int h)
 /*------------------------------------------------------------------*/
 static void
 retrieve_choose_level_xy (int *x1, int *x2, int *x3, int *x4, int *x5,
-			  int *x6, int *y1, int *y2, int *y3, int *y4,
-			  int *y5, int *y6, int *y7, int *y8)
+			  int *x6, int *x7, int *x8, int *y1, int *y2,
+			  int *y3, int *y4, int *y5, int *y6, int *y7,
+			  int *y8)
 {
   (*x1) = (MENU_VIRTUAL_W - MENU_W_LEVEL * 2
 	   - MENU_H_LEVEL * 2
@@ -142,8 +143,10 @@ retrieve_choose_level_xy (int *x1, int *x2, int *x3, int *x4, int *x5,
   (*x2) = (*x1) + MENU_H_SPACE + MENU_H_LEVEL;
   (*x3) = (*x1) + MENU_W_SPACE + MENU_W_LEVEL;
   (*x4) = (*x3) + MENU_H_LEVEL + MENU_H_SPACE;
-  (*x5) = (*x4) + MENU_W_SAMPLE + MENU_W_SPACE;
-  (*x6) = (*x5) + MENU_H_LEVEL + MENU_H_SPACE;
+  (*x5) = (*x4) + MENU_H_SPACE + MENU_H_LEVEL;
+  (*x7) = (*x4) + MENU_W_SAMPLE + MENU_W_SPACE;
+  (*x6) = (*x7) - MENU_H_SPACE - MENU_H_LEVEL;
+  (*x8) = (*x7) + MENU_H_LEVEL + MENU_H_SPACE;
   (*y1) = (MENU_VIRTUAL_H - MENU_H_LEVEL * 4
 	   - MENU_H_SPACE * 4 - MENU_H_SAMPLE) / 2;
   (*y2) = (*y1) + MENU_H_LEVEL + MENU_H_SPACE;
@@ -160,12 +163,13 @@ retrieve_choose_level_xy (int *x1, int *x2, int *x3, int *x4, int *x5,
 static void
 display_chosen_level (void)
 {
-  int x1, x2, x3, x4, x5, x6, y1, y2, y3, y4, y5, y6, y7, y8;
+  int x1, x2, x3, x4, x5, x6, x7, x8;
+  int y1, y2, y3, y4, y5, y6, y7, y8;
   int sample_x, sample_y, sample_w, sample_h;
   int max_w, max_h, bmp_w, bmp_h;
   BITMAP *pour_voir;
-  retrieve_choose_level_xy (&x1, &x2, &x3, &x4, &x5, &x6, &y1, &y2, &y3,
-			    &y4, &y5, &y6, &y7, &y8);
+  retrieve_choose_level_xy (&x1, &x2, &x3, &x4, &x5, &x6, &x7, &x8,
+			    &y1, &y2, &y3, &y4, &y5, &y6, &y7, &y8);
   rectfill (screen, menu_real_x (x4), menu_real_y (y1),
 	    menu_real_x (x4 + MENU_W_SAMPLE) - 1,
 	    menu_real_y (y1 + MENU_H_SAMPLE) - 1, MENU_BG);
@@ -230,8 +234,8 @@ display_chosen_level (void)
        CONFIG_USE_DEFAULT_TEXTURE))
 
     {
-      rectfill (screen, menu_real_x (x6), menu_real_y (y1),
-		menu_real_x (x6 + MENU_W_LEVEL) - 1,
+      rectfill (screen, menu_real_x (x8), menu_real_y (y1),
+		menu_real_x (x8 + MENU_W_LEVEL) - 1,
 		menu_real_y (y1 + MENU_W_LEVEL) - 1, MENU_BG);
       pour_voir =
 	lw_maptex_create_bg (CONFIG_LEVEL_MAP, CONFIG_LEVEL_BG, 0,
@@ -240,7 +244,7 @@ display_chosen_level (void)
 
 	{
 	  stretch_blit (pour_voir, screen, 0, 0, pour_voir->w, pour_voir->h,
-			menu_real_x (x6), menu_real_x (y1),
+			menu_real_x (x8), menu_real_x (y1),
 			menu_real_x (MENU_W_LEVEL),
 			menu_real_x (MENU_W_LEVEL));
 	  destroy_bitmap (pour_voir);
@@ -337,11 +341,11 @@ box_for_choose_map (void)
   DIALOG d[10];
   DIALOG_PLAYER *dp;
   int i;
-  int x1, x2, x3, x4, x5, x6;
+  int x1, x2, x3, x4, x5, x6, x7, x8;
   int y1, y2, y3, y4, y5, y6, y7, y8;
   memset (d, 0, sizeof (d));
-  retrieve_choose_level_xy (&x1, &x2, &x3, &x4, &x5, &x6, &y1, &y2, &y3,
-			    &y4, &y5, &y6, &y7, &y8);
+  retrieve_choose_level_xy (&x1, &x2, &x3, &x4, &x5, &x6, &x7, &x8,
+			    &y1, &y2, &y3, &y4, &y5, &y6, &y7, &y8);
   d[0].x = x4;
   d[0].y = y1;
   d[0].w = MENU_W_SAMPLE;
@@ -350,11 +354,11 @@ box_for_choose_map (void)
   d[1].y = y1;
   d[1].w = MENU_W_LEVEL;
   d[1].h = MENU_W_LEVEL;
-  d[2].x = x6;
+  d[2].x = x8;
   d[2].y = y1;
   d[2].w = MENU_W_LEVEL;
   d[2].h = MENU_W_LEVEL;
-  d[3].x = x6;
+  d[3].x = x8;
   d[3].y = y5;
   d[3].w = MENU_W_LEVEL;
   d[3].h = MENU_H_LEVEL;
@@ -362,7 +366,7 @@ box_for_choose_map (void)
   d[4].y = y4;
   d[4].w = MENU_W_LEVEL;
   d[4].h = MENU_H_LEVEL;
-  d[5].x = x6;
+  d[5].x = x8;
   d[5].y = y4;
   d[5].w = MENU_W_LEVEL;
   d[5].h = MENU_H_LEVEL;
@@ -590,7 +594,7 @@ choose_map (void)
 {
   int retour = 0, choix = MENU_QUICK_BACK;
   int i;
-  int x1, x2, x3, x4, x5, x6;
+  int x1, x2, x3, x4, x5, x6, x7, x8;
   int y1, y2, y3, y4, y5, y6, y7, y8;
   DIALOG d[278];
   char buf1[BUFFER_EDIT_NUMBER + 1];
@@ -602,8 +606,8 @@ choose_map (void)
   display_back_image ();
   set_palette_for_choose_color ();
   quick_buttons (d);
-  retrieve_choose_level_xy (&x1, &x2, &x3, &x4, &x5, &x6, &y1, &y2, &y3,
-			    &y4, &y5, &y6, &y7, &y8);
+  retrieve_choose_level_xy (&x1, &x2, &x3, &x4, &x5, &x6, &x7, &x8,
+			    &y1, &y2, &y3, &y4, &y5, &y6, &y7, &y8);
   d[4].proc = d[5].proc = d[6].proc = my_slider_proc;
   d[4].dp = d[5].dp = d[6].dp = NULL;
   d[4].key = d[5].key = d[6].key = 0;
@@ -622,7 +626,7 @@ choose_map (void)
   d[4].w = MENU_W_SAMPLE;
   d[4].h = MENU_H_LEVEL;
   d[5].x = x3;
-  d[6].x = x5;
+  d[6].x = x7;
   d[5].y = d[6].y = y2;
   d[5].w = d[6].w = MENU_H_LEVEL;
   d[5].h = d[6].h = y4 - y2 - MENU_H_SPACE;
@@ -638,9 +642,9 @@ choose_map (void)
   d[8].dp = d[10].dp = d[12].dp = "+";
   d[7].x = x3;
   d[7].y = d[8].y = y5;
-  d[8].x = x5;
+  d[8].x = x7;
   d[9].x = d[10].x = x3;
-  d[11].x = d[12].x = x5;
+  d[11].x = d[12].x = x7;
   d[9].y = d[11].y = y4;
   d[10].y = d[12].y = y1;
   d[13].proc = d[14].proc = d[15].proc = my_edit_proc;
@@ -650,7 +654,7 @@ choose_map (void)
   d[15].dp = buf3;
   d[13].d1 = d[14].d1 = d[15].d1 = BUFFER_EDIT_NUMBER;
   d[13].d2 = d[14].d2 = d[15].d2 = 0;
-  d[13].x = d[15].x = x6;
+  d[13].x = d[15].x = x8;
   d[14].x = x1;
   d[13].w = d[14].w = d[15].w = MENU_W_LEVEL;
   d[13].h = d[14].h = d[15].h = MENU_H_LEVEL;
@@ -659,35 +663,35 @@ choose_map (void)
   d[16].proc = my_textbox_proc;
   d[16].x = x1;
   d[16].y = y6;
-  d[16].w = x4 - x1 - MENU_W_SPACE;
+  d[16].w = x5 - x1 - MENU_W_SPACE;
   d[16].h = MENU_H_LEVEL;
   d[16].flags = 0;
   d[16].dp = "";
   d[17].proc = my_textbox_proc;
-  d[17].x = x4;
+  d[17].x = x5;
   d[17].y = y6;
-  d[17].w = x6 - x4 + MENU_W_LEVEL;
+  d[17].w = x8 - x5 + MENU_W_LEVEL;
   d[17].h = MENU_H_LEVEL;
   d[17].flags = 0;
   d[17].dp = "";
   d[18].proc = my_textbox_proc;
   d[18].x = x1;
   d[18].y = y7;
-  d[18].w = x5 - x1 - MENU_W_SPACE;
+  d[18].w = x6 - x1 - MENU_W_SPACE;
   d[18].h = MENU_H_LEVEL;
   d[18].flags = 0;
   d[18].dp = lw_lang_string (LW_LANG_STRING_LEVEL_USEDEFAULTTEXTURE);
   d[19].proc = my_button_proc;
-  d[19].x = x5;
+  d[19].x = x6;
   d[19].y = y7;
-  d[19].w = x6 - x5 + MENU_W_LEVEL;
+  d[19].w = x8 - x6 + MENU_W_LEVEL;
   d[19].h = MENU_H_LEVEL;
   d[19].flags = D_EXIT;
   d[19].dp = "";
   d[20].proc = my_button_proc;
   d[20].x = x3;
   d[20].y = y8;
-  d[20].w = x6 - x3 - MENU_W_SPACE;
+  d[20].w = x8 - x3 - MENU_W_SPACE;
   d[20].h = MENU_H_LEVEL;
   d[20].flags = D_EXIT;
   d[20].dp = lw_lang_string (LW_LANG_STRING_LEVEL_RANDOMMAP);;
@@ -704,7 +708,7 @@ choose_map (void)
   palette_128 (d + 21, menu_real_x (x1), menu_real_y (y3),
 	       menu_real_x (MENU_W_LEVEL),
 	       menu_real_y (y4 - y3 - MENU_H_SPACE));
-  palette_128 (d + 149, menu_real_x (x6), menu_real_y (y3),
+  palette_128 (d + 149, menu_real_x (x8), menu_real_y (y3),
 	       menu_real_x (MENU_W_LEVEL),
 	       menu_real_y (y4 - y3 - MENU_H_SPACE));
   box_for_choose_map ();
