@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2005 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -69,7 +69,7 @@
 /*==================================================================*/
 /* construct pour reduire la place d'allegro                        */
 /*==================================================================*/
-#ifdef ALLEGRO_DJGPP
+#ifdef DOS
 
 BEGIN_GFX_DRIVER_LIST
   GFX_DRIVER_VGA
@@ -117,7 +117,7 @@ main (int argc, char **argv)
       load_custom_success = load_custom ();
       log_println ();
 
-#ifdef ALLEGRO_DOS
+#ifdef DOS
       if (STARTUP_STOP)
 	readkey ();
       else
@@ -148,9 +148,9 @@ main (int argc, char **argv)
   return 0;
 }
 
-#ifdef ALLEGRO_WINDOWS
+#ifdef WIN32
 END_OF_MAIN ()
 #endif
-#ifdef ALLEGRO_UNIX
+#ifdef UNIX
   END_OF_MAIN ();
 #endif
