@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2005 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -370,7 +370,7 @@ convert_to_buffer (BITMAP * bmp, char *buffer, int *size, int *bg_size)
 void *
 lw_map_archive_raw_bmp (BITMAP * bmp, PALETTE pal, const char *filename)
 {
-  int w = 0, h = 0, size, bg_size;
+  int w = 0, h = 0, size = 0, bg_size = 0;
   BITMAP *sub_bmp;
   char *temp = NULL;
   char *result = NULL;
