@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2005 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -87,13 +87,13 @@ confirm_quit (void)
   standard_button (d, 0, 0, 2, 1);
   standard_button (d + 1, 1, 0, 2, 1);
   d[0].dp = lw_lang_string (LW_LANG_STRING_MENU_EXIT);
-#ifdef ALLEGRO_DOS
+#ifdef DOS
   d[0].dp = lw_lang_string (LW_LANG_STRING_MENU_EXITDOS);
 #endif
-#ifdef ALLEGRO_WINDOWS
+#ifdef WIN32
   d[0].dp = lw_lang_string (LW_LANG_STRING_MENU_EXITWINDOWS);
 #endif
-#ifdef ALLEGRO_UNIX
+#ifdef UNIX
   d[0].dp = lw_lang_string (LW_LANG_STRING_MENU_EXITUNIX);
 #endif
   d[1].dp = lw_lang_string (LW_LANG_STRING_MENU_BACK);
@@ -156,7 +156,7 @@ main_menu (void)
 	  retour = play_sequence ();
 	  break;
 	case 5:
-#ifndef ALLEGRO_DOS
+#ifndef DOS
 	  retour = network_game ();
 #else
 	  retour = error_no_network_support ();
@@ -182,7 +182,7 @@ main_menu (void)
 	{
 	  if (LW_NETWORK_ON)
 	    {
-#ifndef ALLEGRO_DOS
+#ifndef DOS
 	      retour = netplay_sequence ();
 #else
 	      retour = play_sequence ();
