@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2005 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -232,7 +232,7 @@ decode (LW_NETKEY * dst, LW_NETKEY_SERIALIZED src)
  * Sends a netkey information over the network
  */
 int
-lw_netkey_send (int sock, LW_NETKEY * netkey)
+lw_netkey_send (int *sock, LW_NETKEY * netkey)
 {
   int result;
   LW_NETKEY_SERIALIZED netkey_serialized;
@@ -240,7 +240,8 @@ lw_netkey_send (int sock, LW_NETKEY * netkey)
   encode (netkey_serialized, netkey);
 
   result = lw_sock_send_buffer (sock,
-				netkey_serialized, LW_NETKEY_SERIALIZED_SIZE);
+				(char *) netkey_serialized,
+				LW_NETKEY_SERIALIZED_SIZE);
 
   return result;
 }
@@ -250,13 +251,14 @@ lw_netkey_send (int sock, LW_NETKEY * netkey)
  * Receives a netkey information from the network
  */
 int
-lw_netkey_recv (int sock, LW_NETKEY * netkey)
+lw_netkey_recv (int *sock, LW_NETKEY * netkey)
 {
   int result;
   LW_NETKEY_SERIALIZED netkey_serialized;
 
   result = lw_sock_recv_buffer (sock,
-				netkey_serialized, LW_NETKEY_SERIALIZED_SIZE);
+				(char *) netkey_serialized,
+				LW_NETKEY_SERIALIZED_SIZE);
 
   decode (netkey, netkey_serialized);
 
@@ -268,7 +270,7 @@ lw_netkey_recv (int sock, LW_NETKEY * netkey)
  * Returns true if at leat "num" keys are available on the socket
  */
 int
-lw_netkey_peek (int sock, int num)
+lw_netkey_peek (int *sock, int num)
 {
   int result;
 
