@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2005 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -85,8 +85,8 @@ LW_NETKEY;
 /*==================================================================*/
 
 void lw_netkey_reset (LW_NETKEY * netkey);
-int lw_netkey_send (int sock, LW_NETKEY * netkey);
-int lw_netkey_recv (int sock, LW_NETKEY * netkey);
-int lw_netkey_peek (int sock, int num);
+int lw_netkey_send (int *sock, LW_NETKEY * netkey);
+int lw_netkey_recv (int *sock, LW_NETKEY * netkey);
+int lw_netkey_peek (int *sock, int num);
 
 #endif
