@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2005 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -192,7 +192,7 @@ try_server_callback (void *arg)
 	   get_ticker () < global_start_time + LW_PING_TEST_MAX; ++i)
 	{
 	  start_time = get_ticker ();
-	  result = lw_protocol_do_ping (try_data->sock);
+	  result = lw_protocol_do_ping (&try_data->sock);
 	  if (result == 1)
 	    {
 	      delay[i] = get_ticker () - start_time;
@@ -223,7 +223,7 @@ try_server_callback (void *arg)
        */
       if (result)
 	{
-	  lw_protocol_quit (try_data->sock);
+	  lw_protocol_quit (&try_data->sock);
 	}
       lw_sock_close (&try_data->sock);
     }
