@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2005 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -68,7 +68,7 @@
 /* static functions                                                 */
 /*==================================================================*/
 
-static int recv_ok (int sock);
+static int recv_ok (int *sock);
 
 /*==================================================================*/
 /* fonctions                                                        */
@@ -76,16 +76,15 @@ static int recv_ok (int sock);
 
 /*------------------------------------------------------------------*/
 static int
-recv_ok (int sock)
+recv_ok (int *sock)
 {
   int result = 0;
   char message[LW_SOCK_MESSAGE_SIZE];
-  int ret;
+  int ret = 0;
   LW_NETMESS *netmess;
 
-  while ((ret = lw_sock_recv_str (sock, message)) == 0);
-
-  if (ret > 0)
+  while (*sock >= 0 && (ret = lw_sock_recv_str (sock, message)) == 0);
+  if (*sock >= 0 && ret > 0)
     {
       netmess = lw_netmess_read (message);
       if (netmess != NULL)
@@ -98,7 +97,6 @@ recv_ok (int sock)
 	}
     }
 
-
   return result;
 }
 
@@ -108,11 +106,11 @@ recv_ok (int sock)
  * connection is working OK.
  */
 int
-lw_protocol_do_ping (int sock)
+lw_protocol_do_ping (int *sock)
 {
   int result = 0;
 
-  if (lw_sock_send_str (sock, LW_NETMESS_TEXT_PING))
+  if (*sock >= 0 && lw_sock_send_str (sock, LW_NETMESS_TEXT_PING))
     {
       if (recv_ok (sock))
 	{
@@ -130,13 +128,13 @@ lw_protocol_do_ping (int sock)
  * than a real liquidwar server.
  */
 int
-lw_protocol_tell_program (int sock, char *program)
+lw_protocol_tell_program (int *sock, char *program)
 {
   int result = 0;
   char message[LW_SOCK_MESSAGE_SIZE];
 
   LW_MACRO_SPRINTF2 (message, "%s '%s'", LW_NETMESS_TEXT_PROGRAM, program);
-  if (lw_sock_send_str (sock, message))
+  if (*sock >= 0 && lw_sock_send_str (sock, message))
     {
       if (recv_ok (sock))
 	{
@@ -152,13 +150,13 @@ lw_protocol_tell_program (int sock, char *program)
  * Sends the version of the client to the server.
  */
 int
-lw_protocol_tell_version (int sock, char *version)
+lw_protocol_tell_version (int *sock, char *version)
 {
   int result = 0;
   char message[LW_SOCK_MESSAGE_SIZE];
 
   LW_MACRO_SPRINTF2 (message, "%s '%s'", LW_NETMESS_TEXT_VERSION, version);
-  if (lw_sock_send_str (sock, message))
+  if (*sock >= 0 && lw_sock_send_str (sock, message))
     {
       if (recv_ok (sock))
 	{
@@ -174,13 +172,13 @@ lw_protocol_tell_version (int sock, char *version)
  * Sends the game password to the server.
  */
 int
-lw_protocol_tell_password (int sock, char *password)
+lw_protocol_tell_password (int *sock, char *password)
 {
   int result = 0;
   char message[LW_SOCK_MESSAGE_SIZE];
 
   LW_MACRO_SPRINTF2 (message, "%s '%s'", LW_NETMESS_TEXT_PASSWORD, password);
-  if (lw_sock_send_str (sock, message))
+  if (*sock >= 0 && lw_sock_send_str (sock, message))
     {
       if (recv_ok (sock))
 	{
@@ -196,18 +194,18 @@ lw_protocol_tell_password (int sock, char *password)
  * Asks the server how many players can connect to it.
  */
 int
-lw_protocol_ask_free_teams (int sock, int *nb)
+lw_protocol_ask_free_teams (int *sock, int *nb)
 {
   int result = 0;
   char message[LW_SOCK_MESSAGE_SIZE];
-  int ret;
+  int ret = 0;
   LW_NETMESS *netmess;
 
   *nb = 0;
-  if (lw_sock_send_str (sock, LW_NETMESS_TEXT_FREE))
+  if (*sock >= 0 && lw_sock_send_str (sock, LW_NETMESS_TEXT_FREE))
     {
-      while ((ret = lw_sock_recv_str (sock, message)) == 0);
-      if (ret > 0)
+      while (*sock >= 0 && (ret = lw_sock_recv_str (sock, message)) == 0);
+      if (*sock >= 0 && ret > 0)
 	{
 	  netmess = lw_netmess_read (message);
 	  if (netmess != NULL)
@@ -230,14 +228,14 @@ lw_protocol_ask_free_teams (int sock, int *nb)
  * Inform the server that this player will be playing.
  */
 int
-lw_protocol_reserve_team (int sock, int num, int control_type, char *name)
+lw_protocol_reserve_team (int *sock, int num, int control_type, char *name)
 {
   int result = 0;
   char message[LW_SOCK_MESSAGE_SIZE];
 
   LW_MACRO_SPRINTF4 (message, "%s %d,%d,'%s'",
 		     LW_NETMESS_TEXT_TEAM, num, control_type, name);
-  if (lw_sock_send_str (sock, message))
+  if (*sock >= 0 && lw_sock_send_str (sock, message))
     {
       if (recv_ok (sock))
 	{
@@ -253,11 +251,11 @@ lw_protocol_reserve_team (int sock, int num, int control_type, char *name)
  * Ask the server who is playing on a given channel
  */
 int
-lw_protocol_ask_who (int sock, int num, LW_WHO * who)
+lw_protocol_ask_who (int *sock, int num, LW_WHO * who)
 {
   int result = 0;
   char message[LW_SOCK_MESSAGE_SIZE];
-  int ret;
+  int ret = 0;
   LW_NETMESS *netmess;
 
   who->active = 0;
@@ -266,10 +264,10 @@ lw_protocol_ask_who (int sock, int num, LW_WHO * who)
   who->name[0] = '\0';
 
   LW_MACRO_SPRINTF2 (message, "%s %d", LW_NETMESS_TEXT_WHO, num);
-  if (lw_sock_send_str (sock, message))
+  if (*sock >= 0 && lw_sock_send_str (sock, message))
     {
-      while ((ret = lw_sock_recv_str (sock, message)) == 0);
-      if (ret > 0)
+      while (*sock >= 0 && (ret = lw_sock_recv_str (sock, message)) == 0);
+      if (*sock >= 0 && ret > 0)
 	{
 	  netmess = lw_netmess_read (message);
 	  if (netmess != NULL)
@@ -317,11 +315,11 @@ lw_protocol_ask_who (int sock, int num, LW_WHO * who)
  * Sends the selected map to the server
  */
 int
-lw_protocol_send_map (int sock, void *map)
+lw_protocol_send_map (int *sock, void *map)
 {
   int result = 0;
 
-  if (lw_sock_send_str (sock, LW_NETMESS_TEXT_SENDMAP))
+  if (*sock >= 0 && lw_sock_send_str (sock, LW_NETMESS_TEXT_SENDMAP))
     {
       if (lw_netmap_send (sock, map))
 	{
@@ -340,11 +338,11 @@ lw_protocol_send_map (int sock, void *map)
  * Receives the map from the server
  */
 int
-lw_protocol_recv_map (int sock, void **map)
+lw_protocol_recv_map (int *sock, void **map)
 {
   int result = 0;
 
-  if (lw_sock_send_str (sock, LW_NETMESS_TEXT_RECVMAP))
+  if (*sock >= 0 && lw_sock_send_str (sock, LW_NETMESS_TEXT_RECVMAP))
     {
       if (lw_netmap_recv (sock, map))
 	{
@@ -363,12 +361,12 @@ lw_protocol_recv_map (int sock, void **map)
  * Sends the config to the server
  */
 int
-lw_protocol_send_config (int sock)
+lw_protocol_send_config (int *sock)
 {
   int result = 0;
   LW_NETCONF config;
 
-  if (lw_sock_send_str (sock, LW_NETMESS_TEXT_SENDCONFIG))
+  if (*sock >= 0 && lw_sock_send_str (sock, LW_NETMESS_TEXT_SENDCONFIG))
     {
 
       memcpy (&config, &LW_CONFIG_CURRENT_RULES, sizeof (LW_NETCONF));
@@ -390,12 +388,12 @@ lw_protocol_send_config (int sock)
  * Receives the config from the server
  */
 int
-lw_protocol_recv_config (int sock)
+lw_protocol_recv_config (int *sock)
 {
   int result = 0;
   LW_NETCONF config;
 
-  if (lw_sock_send_str (sock, LW_NETMESS_TEXT_RECVCONFIG))
+  if (*sock >= 0 && lw_sock_send_str (sock, LW_NETMESS_TEXT_RECVCONFIG))
     {
       if (lw_netconf_recv (sock, &config))
 	{
@@ -416,11 +414,11 @@ lw_protocol_recv_config (int sock)
  * Tell the server that the client is ready to play
  */
 int
-lw_protocol_i_am_ready (int sock)
+lw_protocol_i_am_ready (int *sock)
 {
   int result = 0;
 
-  if (lw_sock_send_str (sock, LW_NETMESS_TEXT_READY))
+  if (*sock >= 0 && lw_sock_send_str (sock, LW_NETMESS_TEXT_READY))
     {
       if (recv_ok (sock))
 	{
@@ -436,11 +434,11 @@ lw_protocol_i_am_ready (int sock)
  * Tells the server one is waiting for the game to start
  */
 int
-lw_protocol_waiting (int sock, int *waited_teams)
+lw_protocol_waiting (int *sock, int *waited_teams)
 {
   int result = 0;
   char message[LW_SOCK_MESSAGE_SIZE];
-  int ret;
+  int ret = 0;
   LW_NETMESS *netmess;
 
   /*
@@ -456,10 +454,10 @@ lw_protocol_waiting (int sock, int *waited_teams)
    * (*waited_teams)=NB_TEAMS;
    */
 
-  if (lw_sock_send_str (sock, LW_NETMESS_TEXT_WAITING))
+  if (*sock >= 0 && lw_sock_send_str (sock, LW_NETMESS_TEXT_WAITING))
     {
-      while ((ret = lw_sock_recv_str (sock, message)) == 0);
-      if (ret > 0)
+      while (*sock >= 0 && (ret = lw_sock_recv_str (sock, message)) == 0);
+      if (*sock >= 0 && ret > 0)
 	{
 	  netmess = lw_netmess_read (message);
 	  if (netmess != NULL)
@@ -482,11 +480,11 @@ lw_protocol_waiting (int sock, int *waited_teams)
  * Forces the server to start the game
  */
 int
-lw_protocol_force_start (int sock)
+lw_protocol_force_start (int *sock)
 {
   int result = 0;
 
-  if (lw_sock_send_str (sock, LW_NETMESS_TEXT_START))
+  if (*sock >= 0 && lw_sock_send_str (sock, LW_NETMESS_TEXT_START))
     {
       if (recv_ok (sock))
 	{
@@ -502,11 +500,11 @@ lw_protocol_force_start (int sock)
  * Sends a "NEXT" message
  */
 int
-lw_protocol_next (int sock)
+lw_protocol_next (int *sock)
 {
   int result = 0;
 
-  if (lw_sock_send_str (sock, LW_NETMESS_TEXT_NEXT))
+  if (*sock >= 0 && lw_sock_send_str (sock, LW_NETMESS_TEXT_NEXT))
     {
       if (recv_ok (sock))
 	{
@@ -522,21 +520,21 @@ lw_protocol_next (int sock)
  * Sends a "TEAMSTARTINFO" message
  */
 int
-lw_protocol_ask_teamstartinfo (int sock, int team,
+lw_protocol_ask_teamstartinfo (int *sock, int team,
 			       LW_TEAMSTARTINFO * team_start_info)
 {
   int result = 0;
   char message[LW_SOCK_MESSAGE_SIZE];
-  int ret;
+  int ret = 0;
   LW_NETMESS *netmess;
 
   lw_teamstartinfo_reset (team_start_info);
 
   LW_MACRO_SPRINTF2 (message, "%s %d", LW_NETMESS_TEXT_TEAMSTARTINFO, team);
-  if (lw_sock_send_str (sock, message))
+  if (*sock >= 0 && lw_sock_send_str (sock, message))
     {
-      while ((ret = lw_sock_recv_str (sock, message)) == 0);
-      if (ret > 0)
+      while (*sock >= 0 && (ret = lw_sock_recv_str (sock, message)) == 0);
+      if (*sock >= 0 && ret > 0)
 	{
 	  netmess = lw_netmess_read (message);
 	  if (netmess != NULL)
@@ -569,14 +567,14 @@ lw_protocol_ask_teamstartinfo (int sock, int team,
  * Sends a "CHATTALK" message
  */
 int
-lw_protocol_chat_talk (int sock, char *text)
+lw_protocol_chat_talk (int *sock, char *text)
 {
   int result = 0;
   char message[LW_SOCK_MESSAGE_SIZE];
 
   LW_MACRO_SPRINTF2 (message, "%s '%s'", LW_NETMESS_TEXT_CHATTALK, text);
 
-  if (lw_sock_send_str (sock, message))
+  if (*sock >= 0 && lw_sock_send_str (sock, message))
     {
       if (recv_ok (sock))
 	{
@@ -592,17 +590,17 @@ lw_protocol_chat_talk (int sock, char *text)
  * Sends a "CHATLISTEN" message
  */
 int
-lw_protocol_chat_listen (int sock, LW_CHAT_HISTORY * chat_history)
+lw_protocol_chat_listen (int *sock, LW_CHAT_HISTORY * chat_history)
 {
   int result = 0;
   char message[LW_SOCK_MESSAGE_SIZE];
-  int ret;
+  int ret = 0;
   LW_NETMESS *netmess;
 
-  if (lw_sock_send_str (sock, LW_NETMESS_TEXT_CHATLISTEN))
+  if (*sock >= 0 && lw_sock_send_str (sock, LW_NETMESS_TEXT_CHATLISTEN))
     {
-      while ((ret = lw_sock_recv_str (sock, message)) == 0);
-      if (ret > 0)
+      while (*sock >= 0 && (ret = lw_sock_recv_str (sock, message)) == 0);
+      if (*sock >= 0 && ret > 0)
 	{
 	  netmess = lw_netmess_read (message);
 	  if (netmess != NULL)
@@ -644,7 +642,7 @@ lw_protocol_chat_listen (int sock, LW_CHAT_HISTORY * chat_history)
  * and someones that has network problems.
  */
 int
-lw_protocol_quit (int sock)
+lw_protocol_quit (int *sock)
 {
   int result = 0;
 
