@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2005 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -67,26 +67,36 @@
 /* fonctions globales                                               */
 /*==================================================================*/
 
-int lw_protocol_do_ping (int sock);
-int lw_protocol_tell_version (int sock, char *version);
-int lw_protocol_tell_program (int sock, char *program);
-int lw_protocol_tell_password (int sock, char *password);
-int lw_protocol_ask_free_teams (int sock, int *nb);
-int lw_protocol_reserve_team (int sock, int num,
+/*
+ * IMPORTANT: there's one good reason sock is passed as a pointer
+ * in all these functions. In fact, the code uses constructs like
+ * *(data->sock) = 0 (mostly in connect.c) to intercept network
+ * calls, stop them, and treat GUI stuff and network code in
+ * separate threads. Previous releases of LW (< 5.6.3) didn't do
+ * that, but the bug appeared when trying to release 5.6.3 with
+ * Allegro 4.2 and GCC 4. This is an ugly hack, but hopefully works..
+ */
+
+int lw_protocol_do_ping (int *sock);
+int lw_protocol_tell_version (int *sock, char *version);
+int lw_protocol_tell_program (int *sock, char *program);
+int lw_protocol_tell_password (int *sock, char *password);
+int lw_protocol_ask_free_teams (int *sock, int *nb);
+int lw_protocol_reserve_team (int *sock, int num,
 			      int control_type, char *name);
-int lw_protocol_ask_who (int sock, int num, LW_WHO * who);
-int lw_protocol_send_map (int sock, void *map);
-int lw_protocol_recv_map (int sock, void **map);
-int lw_protocol_send_config (int sock);
-int lw_protocol_recv_config (int sock);
-int lw_protocol_i_am_ready (int sock);
-int lw_protocol_waiting (int sock, int *waited_teams);
-int lw_protocol_force_start (int sock);
-int lw_protocol_next (int sock);
-int lw_protocol_ask_teamstartinfo (int sock, int team,
+int lw_protocol_ask_who (int *sock, int num, LW_WHO * who);
+int lw_protocol_send_map (int *sock, void *map);
+int lw_protocol_recv_map (int *sock, void **map);
+int lw_protocol_send_config (int *sock);
+int lw_protocol_recv_config (int *sock);
+int lw_protocol_i_am_ready (int *sock);
+int lw_protocol_waiting (int *sock, int *waited_teams);
+int lw_protocol_force_start (int *sock);
+int lw_protocol_next (int *sock);
+int lw_protocol_ask_teamstartinfo (int *sock, int team,
 				   LW_TEAMSTARTINFO * team_start_info);
-int lw_protocol_chat_talk (int sock, char *text);
-int lw_protocol_chat_listen (int sock, LW_CHAT_HISTORY * chat_history);
-int lw_protocol_quit (int sock);
+int lw_protocol_chat_talk (int *sock, char *text);
+int lw_protocol_chat_listen (int *sock, LW_CHAT_HISTORY * chat_history);
+int lw_protocol_quit (int *sock);
 
 #endif
