@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2005 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -72,7 +72,7 @@
 
 /*------------------------------------------------------------------*/
 int
-lw_sock_peek (int sock, int len)
+lw_sock_peek (int *sock, int len)
 {
   int result = 0;
 
@@ -83,7 +83,7 @@ lw_sock_peek (int sock, int len)
 
 /*------------------------------------------------------------------*/
 int
-lw_sock_send_str (int sock, char *str)
+lw_sock_send_str (int *sock, char *str)
 {
   int result = 0;
 
@@ -94,7 +94,7 @@ lw_sock_send_str (int sock, char *str)
 
 /*------------------------------------------------------------------*/
 int
-lw_sock_recv_str (int sock, char *str)
+lw_sock_recv_str (int *sock, char *str)
 {
   int result = 0;
 
@@ -105,7 +105,7 @@ lw_sock_recv_str (int sock, char *str)
 
 /*------------------------------------------------------------------*/
 int
-lw_sock_send_buffer (int sock, char *buffer, int len)
+lw_sock_send_buffer (int *sock, char *buffer, int len)
 {
   int result = 0;
 
@@ -116,7 +116,7 @@ lw_sock_send_buffer (int sock, char *buffer, int len)
 
 /*------------------------------------------------------------------*/
 int
-lw_sock_recv_buffer (int sock, char *buffer, int len)
+lw_sock_recv_buffer (int *sock, char *buffer, int len)
 {
   int result = 0;
 
