@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2005 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -60,11 +60,11 @@ int lw_sock_listen (int *sock, int port);
 int lw_sock_accept (int *new_sock, char *ip, int *port,
 		    int listening_sock, int wait);
 int lw_sock_connect (int *sock, char *ip, int port);
-int lw_sock_peek_ex (int sock, int len);
-int lw_sock_send_str_ex (int sock, char *str);
-int lw_sock_recv_str_ex (int sock, char *str);
-int lw_sock_send_buffer_ex (int sock, char *buffer, int len);
-int lw_sock_recv_buffer_ex (int sock, char *buffer, int len);
+int lw_sock_peek_ex (int *sock, int len);
+int lw_sock_send_str_ex (int *sock, char *str);
+int lw_sock_recv_str_ex (int *sock, char *str);
+int lw_sock_send_buffer_ex (int *sock, char *buffer, int len);
+int lw_sock_recv_buffer_ex (int *sock, char *buffer, int len);
 int lw_sock_close (int *sock);
 
 extern int LW_SOCK_LOG;
