@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2005 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -177,7 +177,7 @@ lw_sock_accept (int *new_sock, char *ip, int *port,
 {
   int result = 0;
   struct sockaddr_in name;
-  int namelen = sizeof (struct sockaddr_in);
+  socklen_t namelen = sizeof (struct sockaddr_in);
   fd_set read;
   struct timeval tv;
   int res;
