@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2005 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -138,7 +138,7 @@ lw_srvchan_handle_ping (int sock, LW_NETMESS * mess)
   /*
    * It's a ping, we answer OK everytime
    */
-  lw_sock_send_str (sock, LW_NETMESS_TEXT_OK);
+  lw_sock_send_str (&sock, LW_NETMESS_TEXT_OK);
   result = 1;
 
   return result;
@@ -175,7 +175,7 @@ lw_srvchan_handle_echo (int sock, LW_NETMESS * mess)
       LW_MACRO_STRCAT (answer, mess->argv[i]);
       i++;
     }
-  lw_sock_send_str (sock, answer);
+  lw_sock_send_str (&sock, answer);
   result = 1;
 
   return result;
@@ -209,11 +209,11 @@ lw_srvchan_handle_program (int sock, LW_NETMESS * mess, int *ok)
    */
   if (result)
     {
-      lw_sock_send_str (sock, LW_NETMESS_TEXT_OK);
+      lw_sock_send_str (&sock, LW_NETMESS_TEXT_OK);
     }
   else
     {
-      lw_sock_send_str (sock, LW_NETMESS_TEXT_ERR);
+      lw_sock_send_str (&sock, LW_NETMESS_TEXT_ERR);
     }
 
   return result;
@@ -248,11 +248,11 @@ lw_srvchan_handle_version (int sock, LW_NETMESS * mess, int *ok)
    */
   if (result)
     {
-      lw_sock_send_str (sock, LW_NETMESS_TEXT_OK);
+      lw_sock_send_str (&sock, LW_NETMESS_TEXT_OK);
     }
   else
     {
-      lw_sock_send_str (sock, LW_NETMESS_TEXT_ERR);
+      lw_sock_send_str (&sock, LW_NETMESS_TEXT_ERR);
     }
 
   return result;
@@ -297,11 +297,11 @@ lw_srvchan_handle_password (int sock, LW_NETMESS * mess,
    */
   if (result)
     {
-      lw_sock_send_str (sock, LW_NETMESS_TEXT_OK);
+      lw_sock_send_str (&sock, LW_NETMESS_TEXT_OK);
     }
   else
     {
-      lw_sock_send_str (sock, LW_NETMESS_TEXT_ERR);
+      lw_sock_send_str (&sock, LW_NETMESS_TEXT_ERR);
     }
 
   return result;
@@ -321,7 +321,7 @@ lw_srvchan_handle_free (int sock, LW_NETMESS * mess, int free_teams, int *ok)
 
   LW_MACRO_SPRINTF2 (answer, "%s %d", LW_NETMESS_TEXT_OK, free_teams);
 
-  lw_sock_send_str (sock, answer);
+  lw_sock_send_str (&sock, answer);
 
   (*ok) = 1;
   result = 1;
@@ -400,11 +400,11 @@ handle_team (LW_SRVCHAN * chan, LW_NETMESS * mess, int *free_teams)
    */
   if (result)
     {
-      lw_sock_send_str (chan->sock, LW_NETMESS_TEXT_OK);
+      lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_OK);
     }
   else
     {
-      lw_sock_send_str (chan->sock, LW_NETMESS_TEXT_ERR);
+      lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_ERR);
     }
 
   return result;
@@ -457,7 +457,7 @@ handle_who (LW_SRVCHAN * chan, LW_NETMESS * mess)
 	      LW_MACRO_SPRINTF1 (answer, "%s", LW_NETMESS_TEXT_NOBODY);
 	    }
 
-	  lw_sock_send_str (chan->sock, answer);
+	  lw_sock_send_str (&(chan->sock), answer);
 	  result = 1;
 	}
     }
@@ -467,7 +467,7 @@ handle_who (LW_SRVCHAN * chan, LW_NETMESS * mess)
    */
   if (!result)
     {
-      lw_sock_send_str (chan->sock, LW_NETMESS_TEXT_ERR);
+      lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_ERR);
     }
 
   return result;
@@ -519,11 +519,11 @@ handle_start (LW_SRVCHAN * chan, LW_NETMESS * mess)
    */
   if (result)
     {
-      lw_sock_send_str (chan->sock, LW_NETMESS_TEXT_OK);
+      lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_OK);
     }
   else
     {
-      lw_sock_send_str (chan->sock, LW_NETMESS_TEXT_ERR);
+      lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_ERR);
     }
 
   return result;
@@ -553,11 +553,11 @@ handle_waiting (LW_SRVCHAN * chan, LW_NETMESS * mess, int free_teams)
    */
   if (result)
     {
-      lw_sock_send_str (chan->sock, answer);
+      lw_sock_send_str (&(chan->sock), answer);
     }
   else
     {
-      lw_sock_send_str (chan->sock, LW_NETMESS_TEXT_ERR);
+      lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_ERR);
     }
 
   return result;
@@ -614,7 +614,7 @@ handle_teamstartinfo (LW_SRVCHAN * chan, LW_NETMESS * mess,
 			     team_start_info[i].start,
 			     team_start_info[i].name);
 
-	  lw_sock_send_str (chan->sock, answer);
+	  lw_sock_send_str (&(chan->sock), answer);
 
 	  result = 1;
 	}
@@ -625,7 +625,7 @@ handle_teamstartinfo (LW_SRVCHAN * chan, LW_NETMESS * mess,
    */
   if (!result)
     {
-      lw_sock_send_str (chan->sock, LW_NETMESS_TEXT_ERR);
+      lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_ERR);
     }
 
   return result;
@@ -665,11 +665,11 @@ handle_chattalk (LW_SRVCHAN * chan, LW_NETMESS * mess, LW_CHAT_HISTORY * chat)
    */
   if (result)
     {
-      lw_sock_send_str (chan->sock, LW_NETMESS_TEXT_OK);
+      lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_OK);
     }
   else
     {
-      lw_sock_send_str (chan->sock, LW_NETMESS_TEXT_ERR);
+      lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_ERR);
     }
 
   return result;
@@ -703,7 +703,7 @@ handle_chatlisten (LW_SRVCHAN * chan, LW_NETMESS * mess)
 	  LW_MACRO_SPRINTF0 (answer, LW_NETMESS_TEXT_OK);
 	}
 
-      lw_sock_send_str (chan->sock, answer);
+      lw_sock_send_str (&(chan->sock), answer);
 
       result = 1;
     }
@@ -713,7 +713,7 @@ handle_chatlisten (LW_SRVCHAN * chan, LW_NETMESS * mess)
    */
   if (!result)
     {
-      lw_sock_send_str (chan->sock, LW_NETMESS_TEXT_ERR);
+      lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_ERR);
     }
 
   return result;
@@ -730,18 +730,18 @@ handle_sendmap (LW_SRVCHAN * chan, LW_NETMESS * mess, void **map)
 
   LW_MACRO_NOP (mess);
 
-  result = lw_netmap_recv (chan->sock, map);
+  result = lw_netmap_recv (&(chan->sock), map);
 
   /*
    * Now we send feedback on the network
    */
   if (result)
     {
-      lw_sock_send_str (chan->sock, LW_NETMESS_TEXT_OK);
+      lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_OK);
     }
   else
     {
-      lw_sock_send_str (chan->sock, LW_NETMESS_TEXT_ERR);
+      lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_ERR);
     }
 
 
@@ -759,18 +759,18 @@ handle_recvmap (LW_SRVCHAN * chan, LW_NETMESS * mess, void *map)
 
   LW_MACRO_NOP (mess);
 
-  result = lw_netmap_send (chan->sock, map);
+  result = lw_netmap_send (&(chan->sock), map);
 
   /*
    * Now we send feedback on the network
    */
   if (result)
     {
-      lw_sock_send_str (chan->sock, LW_NETMESS_TEXT_OK);
+      lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_OK);
     }
   else
     {
-      lw_sock_send_str (chan->sock, LW_NETMESS_TEXT_ERR);
+      lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_ERR);
     }
 
   return result;
@@ -787,18 +787,18 @@ handle_sendconfig (LW_SRVCHAN * chan, LW_NETMESS * mess, LW_NETCONF * config)
 
   LW_MACRO_NOP (mess);
 
-  result = lw_netconf_recv (chan->sock, config);
+  result = lw_netconf_recv (&(chan->sock), config);
 
   /*
    * Now we send feedback on the network
    */
   if (result)
     {
-      lw_sock_send_str (chan->sock, LW_NETMESS_TEXT_OK);
+      lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_OK);
     }
   else
     {
-      lw_sock_send_str (chan->sock, LW_NETMESS_TEXT_ERR);
+      lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_ERR);
     }
 
 
@@ -816,18 +816,18 @@ handle_recvconfig (LW_SRVCHAN * chan, LW_NETMESS * mess, LW_NETCONF * config)
 
   LW_MACRO_NOP (mess);
 
-  result = lw_netconf_send (chan->sock, config);
+  result = lw_netconf_send (&(chan->sock), config);
 
   /*
    * Now we send feedback on the network
    */
   if (result)
     {
-      lw_sock_send_str (chan->sock, LW_NETMESS_TEXT_OK);
+      lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_OK);
     }
   else
     {
-      lw_sock_send_str (chan->sock, LW_NETMESS_TEXT_ERR);
+      lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_ERR);
     }
 
   return result;
@@ -876,7 +876,7 @@ lw_srvchan_handle_unknown (int sock, LW_NETMESS * mess)
   /*
    * We answer ERR all the time
    */
-  lw_sock_send_str (sock, LW_NETMESS_TEXT_ERR);
+  lw_sock_send_str (&sock, LW_NETMESS_TEXT_ERR);
 
   /*
    * Since we return 0, the connection will be closed...
@@ -916,7 +916,7 @@ lw_srvchan_wait_teams (LW_SRVCHAN * chan, int *free_teams,
       log_flush ();
 
       while ((!chan->ready_ok) && ret_mess &&
-	     ((ret = lw_sock_recv_str (chan->sock, message)) >= 0))
+	     ((ret = lw_sock_recv_str (&(chan->sock), message)) >= 0))
 	{
 	  if (ret > 0)
 	    {
@@ -1027,7 +1027,7 @@ lw_srvchan_wait_teams (LW_SRVCHAN * chan, int *free_teams,
 	       * network for consistency, since the client did not receive
 	       * any message to his "READY" query yet.
 	       */
-	      lw_sock_send_str (chan->sock, LW_NETMESS_TEXT_ERR);
+	      lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_ERR);
 	    }
 	  lw_sock_close (&(chan->sock));
 
@@ -1077,10 +1077,10 @@ lw_srvchan_keepalive (LW_SRVCHAN * chan,
    * We first answer the "READY" message which had been sent by the
    * client a possibly long time ago.
    */
-  if (lw_sock_send_str (chan->sock, LW_NETMESS_TEXT_OK))
+  if (lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_OK))
     {
       while ((!chan->ready_ok) && (!next) && ret_mess &&
-	     ((ret = lw_sock_recv_str (chan->sock, message)) >= 0))
+	     ((ret = lw_sock_recv_str (&(chan->sock), message)) >= 0))
 	{
 	  if (ret > 0)
 	    {
@@ -1174,7 +1174,7 @@ lw_srvchan_keepalive (LW_SRVCHAN * chan,
 	       * network for consistency, since the client did not receive
 	       * any message to his "READY" query yet.
 	       */
-	      lw_sock_send_str (chan->sock, LW_NETMESS_TEXT_ERR);
+	      lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_ERR);
 	    }
 	  lw_sock_close (&(chan->sock));
 
@@ -1216,10 +1216,10 @@ lw_srvchan_tell_who (LW_SRVCHAN * chan, void *map, LW_NETCONF * config)
    * client a possibly long time ago.
    */
 
-  if (lw_sock_send_str (chan->sock, LW_NETMESS_TEXT_OK))
+  if (lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_OK))
     {
       while ((!chan->ready_ok) && ret_mess &&
-	     ((ret = lw_sock_recv_str (chan->sock, message)) >= 0))
+	     ((ret = lw_sock_recv_str (&(chan->sock), message)) >= 0))
 	{
 	  if (ret > 0)
 	    {
@@ -1291,7 +1291,7 @@ lw_srvchan_tell_who (LW_SRVCHAN * chan, void *map, LW_NETCONF * config)
 	       * network for consistency, since the client did not receive
 	       * any message to his "READY" query yet.
 	       */
-	      lw_sock_send_str (chan->sock, LW_NETMESS_TEXT_ERR);
+	      lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_ERR);
 	    }
 	  lw_sock_close (&(chan->sock));
 
@@ -1311,7 +1311,7 @@ lw_srvchan_final_ok (LW_SRVCHAN * chan)
 {
   int result = 0;
 
-  if (lw_sock_send_str (chan->sock, LW_NETMESS_TEXT_OK))
+  if (lw_sock_send_str (&(chan->sock), LW_NETMESS_TEXT_OK))
     {
       result = 1;
     }
@@ -1398,7 +1398,7 @@ lw_srvchan_recv_keys (LW_SRVCHAN * chan, LW_NETKEY * netkey)
 
   lw_netkey_reset (&chan_netkey);
 
-  result = lw_netkey_recv (chan->sock, &chan_netkey);
+  result = lw_netkey_recv (&(chan->sock), &chan_netkey);
 
   for (i = 0; i < NB_TEAMS; ++i)
     {
@@ -1444,7 +1444,7 @@ lw_srvchan_send_keys (LW_SRVCHAN * chan, LW_NETKEY * netkey)
   chan_netkey.arg = netkey->arg;
   chan_netkey.checksum = chan->checksum_send;
 
-  result = lw_netkey_send (chan->sock, &chan_netkey);
+  result = lw_netkey_send (&(chan->sock), &chan_netkey);
 
   return result;
 }
