@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2005 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -94,7 +94,7 @@
 
 #define STARTUP_MAX_METASERVER_LENGTH      200
 
-#ifdef ALLEGRO_DOS
+#ifdef DOS
 int STARTUP_BIG_DATA = 8;
 #else
 int STARTUP_BIG_DATA = 16;
@@ -116,7 +116,7 @@ int STARTUP_CHECK = 0;
 int STARTUP_CAPTURE = 0;
 int STARTUP_TOMBOLA = 0;
 
-#ifdef ALLEGRO_UNIX
+#ifdef UNIX
 static char *DEFAULT_CFG_PATH = CONFIG_UNIX_CFG;
 static char *DEFAULT_LOG_PATH = "";
 static char *DEFAULT_DAT_PATH = CONFIG_UNIX_DAT;
@@ -126,13 +126,13 @@ static char *DEFAULT_MID_PATH = CONFIG_UNIX_MID;
 static char *DEFAULT_SRV_PATH = CONFIG_UNIX_SRV;
 static char *DEFAULT_GEN_PATH = CONFIG_UNIX_GEN;
 #else
-#ifdef ALLEGRO_WINDOWS
+#ifdef WIN32
 static char *DEFAULT_CFG_PATH = "data/lwwin.cfg";
 static char *DEFAULT_LOG_PATH = "data/lwwin.log";
 static char *DEFAULT_SRV_PATH = "lwwinsrv.exe";
 static char *DEFAULT_GEN_PATH = "lwwinmap.exe";
 #endif
-#ifdef ALLEGRO_DOS
+#ifdef DOS
 static char *DEFAULT_CFG_PATH = "data/lwdos.cfg";
 static char *DEFAULT_LOG_PATH = "data/lwdos.log";
 static char *DEFAULT_SRV_PATH = "";
@@ -322,7 +322,7 @@ set_path (void)
     }
   else
     {
-#ifdef ALLEGRO_UNIX
+#ifdef UNIX
       home_env = getenv ("HOME");
       if (home_env != NULL)
 	{
