@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2005 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -169,7 +169,7 @@ page_flip (void)
       new_h = old_h ? 0 : SCREEN_H;
 
       scroll_screen (0, old_h);
-      set_clip (screen, 0, new_h, SCREEN_W - 1, new_h + SCREEN_H - 1);
+      set_clip_rect (screen, 0, new_h, SCREEN_W - 1, new_h + SCREEN_H - 1);
 
       PAGE_FLIP_H = new_h;
 
@@ -183,7 +183,7 @@ page_flip (void)
       if (VIEWPORT_CHANGE_REGISTERED || !NEXT_SCREEN)
 	{
 	  scroll_screen (0, 0);
-	  set_clip (screen, 0, 0, SCREEN_W - 1, SCREEN_H - 1);
+	  set_clip_rect (screen, 0, 0, SCREEN_W - 1, SCREEN_H - 1);
 
 	  lw_info_get_room_for_viewport (&x, &y, &w, &h);
 	  init_viewport_size (x, y, w, h);
@@ -212,7 +212,7 @@ last_flip (void)
     {
       if (CONFIG_PAGE_FLIP && VIRTUAL_H >= (2 * SCREEN_H))
 	{
-	  set_clip (screen, 0, 0, SCREEN_W - 1, SCREEN_H - 1);
+	  set_clip_rect (screen, 0, 0, SCREEN_W - 1, SCREEN_H - 1);
 	  if (!PAGE_FLIP_H)
 	    {
 	      blit (screen, screen, 0, SCREEN_H, 0, 0, SCREEN_W, SCREEN_H);
