@@ -22,7 +22,7 @@
 
 /*****************************************************************************/
 /* Liquid War is a multiplayer wargame                                       */
-/* Copyright (C) 1998-2004 Christian Mauduit                                 */
+/* Copyright (C) 1998-2005 Christian Mauduit                                 */
 /*                                                                           */
 /* This program is free software; you can redistribute it and/or modify      */
 /* it under the terms of the GNU General Public License as published by      */
@@ -48,6 +48,12 @@
 /* date de modif : March 2000                                       */
 /********************************************************************/
 
+/*=================================================================*/
+/* defines                                                         */
+/*=================================================================*/
+
+#define ALLEGRO_USE_CONSOLE
+
 /*=================================================================*/
 /* includes                                                        */
 /*=================================================================*/
