@@ -8,18 +8,15 @@
 #ifndef LWMAPGEN_MISC_H
 #define LWMAPGEN_MISC_H
 
-#ifndef UNIX
-#define __inline__
-#endif
 
 /* a random number from min to max inclusive on both ends */
-__inline__ int rand_num( int min, int max);
+int rand_num( int min, int max);
 
 
 /* size == the size of the elements in the array/grid */
 
 void * create_array( int length, int size );
-__inline__ void delete_array( void *array );
+void delete_array( void *array );
 
 void ** create_grid( int r, int c, int size );
 void delete_grid( void **grid, int r );
